<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class XforWC_Improved_Badges_Frontend {

	public static $settings;

	protected static $_instance = null;

	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	function __construct() {
		if ( 'yes' === SevenVXGet()->get_option_autoload( 'wc_settings_isb_template_overrides', 'yes' ) ) {
			add_filter( 'wc_get_template_part', array( $this, 'isb_add_loop_filter' ), 10, 3 );
			add_filter( 'woocommerce_locate_template', array( $this, 'isb_add_loop_filter' ), 10, 3 );
		} else {
			$this->install_shop();
			$this->install_product_page();
		}
		
		add_action( 'init', array( $this, 'init_settings' ), 1999 );

		add_action( 'wp_enqueue_scripts', array( $this, 'isb_scripts' ) );
		add_action( 'wp_footer', array( $this, 'check_scripts' ) );

		add_action( 'xforwc_badges_loop', array( $this, '_get_badge' ), 10 );
		add_action( 'xforwc_badges_product', array( $this, '_get_badge' ), 10 );

		add_action( 'isb_get_loop_badge', array( $this, 'isb_get_loop_badge' ), 10 );
		add_action( 'isb_get_single_badge', array( $this, 'isb_get_single_badge' ), 10 );

		add_filter( 'xforwc__add_meta_information_used', array( $this, 'isb_info' ) );
	}

	protected $time = '';

	function init_settings() {
		$this->create_primary_badge();

		$this->time = strtotime( current_time( 'mysql' ) );
	}

	function isb_info( $val ) {
		$val = array_merge( $val, array( 'Improved Badges for WooCommerce' ) );
		return $val;
	}

	public static function isb_get_path() {
		return plugin_dir_path( __FILE__ );
	}

	function install_shop() {
		$common_action = SevenVXGet()->get_option_autoload( 'isb_common_shop_action', '' );
		$custom_action = SevenVXGet()->get_option_autoload( 'wc_settings_isb_archive_action', '' );
		$priority = (int) SevenVXGet()->get_option_autoload( 'isb_shop_action_priority', '' );

		if ( $priority < 0 ) {
			$priority = 10;
		}

		if ( !empty( $common_action ) ) {
			add_action( $common_action, array( $this, 'isb_get_loop_badge' ), $priority );
		} else if ( !empty( $custom_action ) ) {
			add_action( $custom_action, array( $this, 'isb_get_loop_badge' ), $priority );
		}
	}

	function install_product_page() {
		$common_action = SevenVXGet()->get_option_autoload( 'isb_common_product_action', '' );
		$custom_action = SevenVXGet()->get_option_autoload( 'wc_settings_isb_single_action', '' );
		$priority = (int) SevenVXGet()->get_option_autoload( 'isb_product_action_priority', '' );

		if ( $priority < 0 ) {
			$priority = 10;
		}

		if ( !empty( $common_action ) ) {
			add_action( $common_action, array( $this, 'isb_get_single_badge' ), $priority );
		} else if ( !empty( $custom_action ) ) {
			add_action( $custom_action, array( $this, 'isb_get_single_badge' ), $priority );
		}
	}

	function isb_scripts() {
		wp_enqueue_style( 'isb-style', ImprovedBadges()->plugin_url() . '/assets/css/styles' . ( is_rtl() ? '-rtl' : '' ) . '.css', false, XforWC_Improved_Badges::$version );

		wp_register_script( 'isb-scripts', ImprovedBadges()->plugin_url() . '/assets/js/scripts.js', array( 'jquery' ), XforWC_Improved_Badges::$version, true );
		wp_enqueue_script( 'isb-scripts' );
	}

	function check_scripts() {
		if ( ! isset( $this->load_js ) && 'no' === SevenVXGet()->get_option_autoload( 'wc_settings_isb_force_scripts', 'no' ) ) {
			wp_dequeue_script( 'isb-scripts' );
		} elseif ( wp_script_is( 'isb-scripts', 'enqueued' ) ) {

			$curr_args = array(
				'time'         => $this->time,
				'localization' => array(
					'd'    => esc_html__( 'd', '^xwc' ),
					'days' => esc_html__( 'days', '^xwc' ),
				),
			);

			wp_localize_script( 'isb-scripts', 'isb', $curr_args );

		}
	}

	function isb_add_loop_filter( $template, $slug, $path ) {
		if ( in_array( $slug, array( 'loop/sale-flash.php', 'single-product/sale-flash.php' ), true ) ) {
			$badge = ImprovedBadges()->plugin_path() . '/woocommerce/' . $slug;
			return file_exists( $badge ) ? $badge : $template;
		}
		return $template;
	}

	function isb_get_loop_badge() {

		$include = ImprovedBadges()->plugin_path() . '/woocommerce/loop/sale-flash.php';

		if ( file_exists( $include ) ) {
			include $include;
		}

	}

	function isb_get_single_badge() {

		$include = ImprovedBadges()->plugin_path() . '/woocommerce/single-product/sale-flash.php';

		if ( file_exists( $include ) ) {
			include $include;
		}

	}

	protected $primary_badge = array();

	function create_primary_badge() {
		if ( !empty( $this->primary_badge ) ) {
			return $this->primary_badge;
		}

		$set = SevenVXGet()->get_option( 'primary_badge', 'improved_badges', array() );

		if ( !empty( $set ) && is_array( $set ) ) {
			foreach( $set as $k => $v ) {
				$this->primary_badge[] = $this->_build_current_badge_set( self::get_preset( $v ) );
			}
		}

		return $this->get_default_set();
	}

	function get_default_set() {
		return array();
	}

	protected $load_js = false;

	function _get_badge() {

		global $product, $isb_set;

		if ( empty( $product ) ) {
			return '';
		}

		if ( $product->is_type( 'grouped' ) ) {
			return '';
		}

		$curr_badge   = $this->get_badge();

		$custom_badge = isset( $curr_badge[0]['type'] ) && in_array( $curr_badge[0]['type'], array( 'sale', 'special', 'image', 'image-sale', 'image-special' ), true );

		if ( ! $custom_badge ) {
			return '';
		}

		$badge_count = count( $curr_badge );

		if ( $badge_count > 1 ) {
			?>
				<div class="isb_badges">
			<?php
		}

		for ( $i = 0; $i < $badge_count; $i++ ) {
			$this->_print_badge( $curr_badge[0]['type'], $curr_badge );

			array_shift( $curr_badge );
		}

		if ( $badge_count > 1 ) {
			?>
				</div>
			<?php
		}

		$this->load_js = true;
	}

	public static function get_preset( $preset ) {

		if ( '' === $preset ) {
			return array();
		}

		if ( is_string( $preset ) ) {
			return self::get_presets( array( $preset ) );
		}

		if ( is_array( $preset ) ) {
			if ( isset( $preset['preset'] ) ) {
				if ( is_string( $preset['preset'] ) ) {
					return self::get_presets( array( sanitize_title( $preset['preset'] ) ) );
				}
				if ( is_array( $preset['preset'] ) ) {
					return self::get_presets( $preset['preset'] );
				}
			} else {
				return self::get_presets( $preset );
			}
		}
	}

	public static function get_presets( $preset ) {
		$badges = array();

		foreach ( $preset as $k => $v ) {
			$badge = get_option( '_wcmn_isb_preset_' . $v, array() );

			if ( isset( $badge['name'] ) ) {
				$badges[ $k ] = $badge;
			}
		}

		return $badges;
	}

	public static function is_old_post( $id, $days = 5 ) {
		$days   = (int) $days;
		$offset = $days * 60 * 60 * 24;
		if ( get_post_time( 'U', false, $id ) < gmdate( 'U' ) - $offset ) {
			return true;
		}

		return false;
	}

	function is_old() {
		$post_time = get_post_time( 'U', false, get_the_ID() );
		$current_time = $this->get_current_time();

		if ( $post_time < $current_time ) {
			return true;
		}

		return false;
	}

	protected $current_time = false;

	function get_current_time() {
		if ( $this->current_time ) {
			return $this->current_time;
		}
		
		$days   = (int) SevenVXGet()->get_option( 'new_badge_period', 'improved_badges', 7 );
		$this->current_time = gmdate( 'U' ) - ( $days * 60 * 60 * 24 );

		return $this->current_time;
	}

	function _print_badge( $type, $curr_badge ) {

		switch ( $type ) {
			case 'special':
				$this->print_special_badge( $curr_badge );
				break;

			case 'sale':
			case 'image-sale':
				global $product;

				if ( $product->is_type( 'variable' ) ) {
					$this->print_variable_sale_badge( $curr_badge, $type );
				} else {
					$this->print_standard_sale_badge( $curr_badge, $type );
				}
				break;

			case 'image':
				$this->print_image_badge( $curr_badge );
				break;

			case 'image-special':
				$this->print_image_special_badge( $curr_badge );
				break;

			default:
				break;
		}

	}

	function print_image_badge( $badge ) {

		$badge_set = $this->_build_current_badge_set( $badge );
		$badge_set['class'] = $badge_set['position'];

		if ( isset( $badge_set['image'] ) ) {
			XforWC_Improved_Badges_GetBadge()->get_badge( 'image', $badge_set, array() );
		}
	}

	function print_image_special_badge( $badge ) {

		$badge_set = $this->_build_current_badge_set( $badge );
		$badge_set['class'] = $badge_set['position'];

		if ( isset( $badge_set['image'] ) ) {
			XforWC_Improved_Badges_GetBadge()->get_badge( 'image-special', $badge_set, array() );
		}
	}

	function print_special_badge( $badge ) {

		$badge_set = $this->_build_current_badge_set( $badge );
		$badge_set['class'] = $badge_set['special'] . ' ' . $badge_set['color'] . ' ' . $badge_set['position'];

		if ( isset( $badge_set['special'] ) ) {
			XforWC_Improved_Badges_GetBadge()->get_badge( 'special', $badge_set, array() );
		}
	}

	function print_variable_sale_badge( $badge, $type ) {
		global $product;

		$isb_variations = $product->get_available_variations();
		$isb_check      = 0;
		$isb_check_time = 0;

		if ( ! empty( $isb_variations ) ) {
			$badge_set = $this->_build_current_badge_set( $badge );
			$badge_set['class']    = $badge_set['style'] . ' ' . $badge_set['color'] . ' ' . $badge_set['position'] . ' isb_variable';
			?>
			<div class="isb_variable_group <?php echo esc_attr( $badge_set['position'] ); ?>">
			<?php
		}

		foreach ( $isb_variations as $var ) {

			$curr_product[ $var['variation_id'] ] = new WC_Product_Variation( $var['variation_id'] );
			$isb_price                            = array();

			$sale_price_dates_from = (int) get_post_meta( $var['variation_id'], '_sale_price_dates_from', true ) + (int) SevenVXGet()->get_option( 'wc_settings_isb_timer_adjust', 'improved_badges', 0 ) * 60;
			$sale_price_dates_to   = (int) get_post_meta( $var['variation_id'], '_sale_price_dates_to', true ) + (int) SevenVXGet()->get_option( 'wc_settings_isb_timer_adjust', 'improved_badges', 0 ) * 60;

			if ( ! empty( $sale_price_dates_from ) && ! empty( $sale_price_dates_to ) ) {
				$current_time = current_time( 'mysql' );
				$newer_date   = strtotime( $current_time );

				$since = $newer_date - $sale_price_dates_from;

				if ( 0 > $since ) {
					$check_time      = $sale_price_dates_from;
					$check_time_mode = 'start';
				}

				if ( ! isset( $check_time ) ) {
					$since = $newer_date - $sale_price_dates_to;
					if ( 0 > $since ) {
						$check_time      = $sale_price_dates_to;
						$check_time_mode = 'end';
					}
				}

				if ( isset( $check_time ) ) {
					$isb_price['time']      = $check_time;
					$isb_price['time_mode'] = $check_time_mode;

					$timer = SevenVXGet()->get_option( 'wc_settings_isb_timer', 'improved_badges', array() );
					if ( ! empty( $timer ) && is_array( $timer ) && isset( $isb_price['time_mode'] ) && in_array( $isb_price['time_mode'], $timer, true ) ) {
						unset( $isb_price['time'] );
						unset( $isb_price['time_mode'] );
					}
				}
			}

			if ( $curr_product[ $var['variation_id'] ]->get_price() > 0 && ( $curr_product[ $var['variation_id'] ]->is_on_sale() || false !== isset( $isb_price['time'] ) ) ) {

				$isb_var_regular_price = $curr_product[ $var['variation_id'] ]->get_regular_price();
				$isb_var_sales_price   = $curr_product[ $var['variation_id'] ]->get_sale_price();

				$isb_diff = $isb_var_regular_price - $isb_var_sales_price;

				if ( $isb_diff > $isb_check ) {
					$isb_check = $isb_diff;
					$isb_var   = $var['variation_id'];
				}

				$this->check_sale_labels( 'variable', $var['variation_id'], $curr_product[ $var['variation_id'] ], $isb_price );

				XforWC_Improved_Badges_GetBadge()->get_badge( $type, $badge_set, $isb_price );
			}
		}

		if ( isset( $isb_var ) ) {
			$this->check_sale_labels( 'variable', 0, $curr_product[ $isb_var ], $isb_price );

			XforWC_Improved_Badges_GetBadge()->get_badge( $type, $badge_set, $isb_price );
		}

		if ( ! empty( $isb_variations ) ) {
			?>
			</div>
			<?php
		}

	}

	function _build_current_badge_set( $curr_badge ) {
		return array(
			'type'         => isset( $curr_badge[0]['type'] ) && '' !== $curr_badge[0]['type'] ? $curr_badge[0]['type'] : '',
			'style'        => isset( $curr_badge[0]['style'] ) && '' !== $curr_badge[0]['style'] ? $curr_badge[0]['style'] : '',
			'color'        => isset( $curr_badge[0]['color'] ) && '' !== $curr_badge[0]['color'] ? $curr_badge[0]['color'] : '',
			'position'     => isset( $curr_badge[0]['position'] ) && '' !== $curr_badge[0]['position'] ? $curr_badge[0]['position'] : '',
			'special'      => isset( $curr_badge[0]['special'] ) && '' !== $curr_badge[0]['special'] ? $curr_badge[0]['special'] : '',
			'special_text' => isset( $curr_badge[0]['special_text'] ) && '' !== $curr_badge[0]['special_text'] ? stripslashes( $curr_badge[0]['special_text'] ) : esc_html__( 'Text', '^xwc' ),
			'image'        => isset( $curr_badge[0]['image'] ) && '' !== $curr_badge[0]['image'] ? $curr_badge[0]['image'] : '',
			'image_width'  => isset( $curr_badge[0]['image_width'] ) && '' !== $curr_badge[0]['image_width'] ? $curr_badge[0]['image_width'] : 'isb_image_width_60',
		);
	}

	function check_sale_labels( $type, $id, $product, &$isb_price ) {

		$isb_price['type'] = $type;

		$isb_price['id'] = $id;

		$isb_price['regular'] = floatval( $product->get_regular_price() );

		$isb_price['sale'] = floatval( $product->get_sale_price() );

		$isb_price['difference'] = $isb_price['regular'] - $isb_price['sale'];

		$isb_price['percentage'] = round( ( $isb_price['regular'] - $isb_price['sale'] ) * 100 / $isb_price['regular'] );

	}

	function get_dates_from( $id ) {
		return (int) get_post_meta( $id, '_sale_price_dates_from', true ) + (int) SevenVXGet()->get_option( 'wc_settings_isb_timer_adjust', 'improved_badges', 0 ) * 60;
	}

	function get_dates_to( $id ) {
		return (int) get_post_meta( $id, '_sale_price_dates_to', true ) + (int) SevenVXGet()->get_option( 'wc_settings_isb_timer_adjust', 'improved_badges', 0 ) * 60;
	}

	function check_sale_dates( &$isb_price ) {
		$sale_price_dates_from = $this->get_dates_from( get_the_ID() );
		$sale_price_dates_to   = $this->get_dates_to( get_the_ID() );

		if ( ! empty( $sale_price_dates_from ) && ! empty( $sale_price_dates_to ) ) {
			$current_time = current_time( 'mysql' );
			$newer_date   = strtotime( $current_time, $sale_price_dates_from );

			$since = $newer_date - $sale_price_dates_from;

			if ( 0 > $since ) {
				$isb_price['time']      = $sale_price_dates_from;
				$isb_price['time_mode'] = 'start';
			}

			if ( ! isset( $isb_price['time'] ) ) {
				$since = $newer_date - $sale_price_dates_to;
				if ( 0 > $since ) {
					$isb_price['time']      = $sale_price_dates_to;
					$isb_price['time_mode'] = 'end';
				}
			}

			$timer = SevenVXGet()->get_option( 'wc_settings_isb_timer', 'improved_badges', array() );
			if ( ! empty( $timer ) && is_array( $timer ) && isset( $isb_price['time_mode'] ) && in_array( $isb_price['time_mode'], $timer, true ) ) {
				unset( $isb_price['time'] );
				unset( $isb_price['time_mode'] );
			}
		}
	}

	function print_standard_sale_badge( $badge, $type ) {
		global $product;

		$isb_price = array();
		$this->check_sale_dates( $isb_price );

		if ( $product->get_price() > 0 && false !== ( $product->is_on_sale() || isset( $isb_price['time'] ) ) ) {
			$this->check_sale_labels( 'simple', get_the_ID(), $product, $isb_price );
			$badge_set = $this->_build_current_badge_set( $badge );
			$badge_set['class'] = $badge_set['style'] . ' ' . $badge_set['color'] . ' ' . $badge_set['position'];

			XforWC_Improved_Badges_GetBadge()->get_badge( $type, $badge_set, $isb_price );
		}
	}

	function get_badge() {
		$badge = $this->primary_badge;

		$badge_meta = get_post_meta( get_the_ID(), '_isb_settings' );

		if ( isset( $badge_meta[0]['preset'] ) && '' !== $badge_meta[0]['preset'] ) {
			$preset = self::get_preset( $badge_meta[0]['preset'] );
			if ( ! empty( $preset ) ) {
				return $preset;
			}
		}

		$override = $this->overrides();
		$badge    = empty( $override ) ? $badge : $override;

		$addons = $this->addons();
		$badge    = empty( $addons ) ? $badge : array_merge( $badge, $addons );

		return $badge;
	}

	function fix_presets($mode, $taxonomy) {
		if ( empty( self::$settings[$mode][$taxonomy] ) ) {
			self::$settings[$mode][$taxonomy] = array();
		} else {
			foreach( self::$settings[$mode][$taxonomy] as $k => $v ) {
				if ( !isset( $v['term'], $v['preset'] ) ) {
					continue;
				}

				self::$settings[$mode][$taxonomy][ $v['term'] ] = $v['preset'];
			}
		}
	}

	function addons() {

		if ( ! isset( self::$settings['addons'] ) ) {
			self::$settings['addons'] = SevenVXGet()->get_option( 'wcmn_isb_addons', 'improved_badges', array() );

			$this->fix_presets('addons', 'product_cat');
			$this->fix_presets('addons', 'product_tag');
		}

		if ( empty( self::$settings['addons'] ) ) {
			return false;
		}

		$addon_badges = array();

		if ( isset( self::$settings['addons']['outofstock'] ) && '' !== self::$settings['addons']['outofstock'] ) {
			global $product;

			if ( false === $product->is_in_stock() ) {
				$addon_badges = $addon_badges + self::get_preset( self::$settings['addons']['outofstock'] );
			}
		}

		if ( isset( self::$settings['addons']['featured'] ) && '' !== self::$settings['addons']['featured'] ) {
			if ( has_term( 'featured', 'product_visibility', get_the_ID() ) ) {
				$addon_badges = $addon_badges + self::get_preset( self::$settings['addons']['featured'] );
			}
		}

		if ( isset( self::$settings['addons']['recent'] ) && '' !== self::$settings['addons']['recent'] ) {
			if ( ! $this->is_old() ) {
				$addon_badges = $addon_badges + self::get_preset( self::$settings['addons']['recent'] );
			}
		}

		if ( isset( self::$settings['addons']['sale'] ) && '' !== self::$settings['addons']['sale'] ) {
			global $product;

			if ( $product->get_price() > 0 && $product->is_on_sale() ) {
				$addon_badges = $addon_badges + self::get_preset( self::$settings['addons']['sale'] );
			}
		}

		$this->get_badges_for_taxonomy( 'product_cat' , $addon_badges );
		$this->get_badges_for_taxonomy( 'product_tag' , $addon_badges );

		return $addon_badges;
	}

	function get_badges_for_taxonomy( $taxonomy, &$badges = array() ) {
		if ( empty( self::$settings['addons'][$taxonomy] ) ) {
			return;
		}

		if ( isset( self::$settings['addons'][$taxonomy] ) && is_array( self::$settings['addons'][$taxonomy] ) ) {
			$term_ids = wp_get_post_terms( get_the_ID(), $taxonomy, array( 'fields' => 'ids' ) );

			if ( $term_ids && ! is_wp_error( $term_ids ) ) {
				foreach ( $term_ids as $term_id ) {
					if ( array_key_exists( $term_id, self::$settings['addons'][$taxonomy] ) ) {
						$badges = $badges + self::get_preset( self::$settings['addons'][$taxonomy][ $term_id ] );
					}
				}
			}
		}
	}
	
	function overrides() {

		if ( ! isset( self::$settings['overrides'] ) ) {
			self::$settings['overrides'] = SevenVXGet()->get_option( 'wcmn_isb_overrides', 'improved_badges', array() );
			
			$this->fix_presets('overrides', 'product_cat');
			$this->fix_presets('overrides', 'product_tag');
		}

		if ( empty( self::$settings['overrides'] ) ) {
			return false;
		}

		if ( isset( self::$settings['overrides']['outofstock'] ) && '' !== self::$settings['overrides']['outofstock'] ) {
			global $product;

			if ( false === $product->is_in_stock() ) {
				return self::get_preset( self::$settings['overrides']['outofstock'] );
			}
		}

		if ( isset( self::$settings['overrides']['featured'] ) && '' !== self::$settings['overrides']['featured'] ) {
			if ( get_post_meta( get_the_ID(), '_featured', true ) === 'yes' ) {
				return self::get_preset( self::$settings['overrides']['featured'] );
			}
		}

		if ( isset( self::$settings['overrides']['recent'] ) && '' !== self::$settings['overrides']['recent'] ) {
			if ( ! $this->is_old() ) {
				return self::get_preset( self::$settings['overrides']['recent'] );
			}
		}

		$products_tags = $this->get_badges_for_taxonomy_overrides('product_tag');
		if ( ! empty( $products_tags ) ) {
			return $products_tags;
		}

		$products_cats = $this->get_badges_for_taxonomy_overrides('product_cat');
		if ( ! empty( $products_cats ) ) {
			return $products_cats;
		}

		if ( isset( self::$settings['overrides']['sale'] ) && '' !== self::$settings['overrides']['sale'] ) {
			global $product;

			if ( $product->get_price() > 0 && $product->is_on_sale() ) {
				return self::get_preset( self::$settings['overrides']['sale'] );
			}
		}

		return array();

	}

	function get_badges_for_taxonomy_overrides( $taxonomy ) {
		if ( empty( self::$settings['overrides'][$taxonomy] ) ) {
			return array();
		}

		if ( isset( self::$settings['overrides'][$taxonomy] ) && is_array( self::$settings['overrides'][$taxonomy] ) ) {
			$term_ids = wp_get_post_terms( get_the_ID(), $taxonomy, array( 'fields' => 'ids' ) );

			if ( is_taxonomy_hierarchical( $taxonomy ) ) {
				$term_parents = get_ancestors( $term_ids[0], $taxonomy );
	
				$term_ids = array( $term_ids[0] );
				if ( ! empty( $term_parents ) ) {
					$term_ids = array_merge( $term_ids, $term_parents );
				}
			}
	
			if ( $term_ids && ! is_wp_error( $term_ids ) ) {
				foreach ( $term_ids as $term_id ) {
					if ( array_key_exists( $term_id, self::$settings['overrides'][$taxonomy] ) ) {
						return self::get_preset( self::$settings['overrides'][$taxonomy][ $term_id ] );
					}
				}
			}
		}

		return array();
	}

}

add_action( 'init', array( 'XforWC_Improved_Badges_Frontend', 'instance' ), 998 );

function XforWC_Improved_Badges_Frontend() {
	return XforWC_Improved_Badges_Frontend::instance();
}


if ( ! function_exists( 'xforwc__add_meta_information' ) ) {
	function xforwc__add_meta_information_action() {
		echo '<meta name="generator" content="XforWooCommerce.com - ' . esc_attr( implode( ' - ', apply_filters( 'xforwc__add_meta_information_used', array() ) ) ) . '"/>';
	}
	function xforwc__add_meta_information() {
		add_action( 'wp_head', 'xforwc__add_meta_information_action', 99 );
	}
	xforwc__add_meta_information();
}

