<?php

if (!defined('ABSPATH')) {
    exit;
}

class XforWC_Improved_Badges_GetBadge
{
    protected static $_instance = null;

    public static function instance()
    {

        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }

    function __construct()
    {
    }

    function get_badge($type, $badge, $product)
    {
        $badge_name = '';

        $this->set_product($product);

        $this->set_badge($badge);

        switch ($type) {
            case 'sale':
                $badge_name = $badge['style'];
                break;
            case 'special':
                $badge_name = $badge['special'];
                break;
            case 'image-sale':
                $badge_name = 'isb_image_sale';
                break;
            case 'image-special':
                $badge_name = 'isb_image_special';
                break;
            case 'image':
                $badge_name = 'isb_image';
                break;
            default:
                break;
        }

        // Check if method exists in this class
        if ($badge_name && method_exists($this, 'get_badge_' . $badge_name)) {
            call_user_func(array($this, 'get_badge_' . $badge_name));
        } else {
            return false;
        }
    }

    private $product = array();

    function set_product($product)
    {
        $this->product = $product;
    }

    function get_product_prop($prop)
    {
        if (isset($this->product[$prop])) {
            return $this->product[$prop];
        } else {
            return false;
        }
    }

    private $badge = array();

    function set_badge($badge)
    {
        $this->badge = $badge;
    }

    function get_badge_prop($prop)
    {
        if (isset($this->badge[$prop])) {
            return $this->badge[$prop];
        } else {
            return false;
        }
    }

    function print_time($style = 'default')
    {
        if (!isset($this->product['time'])) {
            return '';
        }

        $style_class = '';
        switch ($style) {
            default:
            case 'default':
                $style_class = 'isb_scheduled_sale isb_scheduled_' . $this->product['time_mode'] . ' ' . $this->badge['color'];
                break;
            case 'text':
                $style_class = 'isb_scheduled_sale isb_scheduled_' . $this->product['time_mode'] . ' isb_color';
                break;
            case 'inherit':
                $style_class = 'isb_scheduled_sale isb_scheduled_' . $this->product['time_mode'];
                break;
        }
?>
        <div class="<?php echo esc_attr($style_class); ?>">
            <span class="isb_scheduled_text">
                <?php
                if ('start' === $this->product['time_mode']) {
                    esc_html_e('Starts in', '^xwc');
                } else {
                    esc_html_e('Ends in', '^xwc');
                }
                ?>
            </span>
            <span class="isb_scheduled_time isb_scheduled_compact">
                <?php echo esc_html($this->product['time']); ?>
            </span>
        </div>
    <?php
    }

    function build_badge_set($badge)
    {
        return array(
            'type'         => isset($badge['type']) && '' !== $badge['type'] ? $badge['type'] : '',
            'style'        => isset($badge['style']) && '' !== $badge['style'] ? $badge['style'] : '',
            'color'        => isset($badge['color']) && '' !== $badge['color'] ? $badge['color'] : '',
            'position'     => isset($badge['position']) && '' !== $badge['position'] ? $badge['position'] : '',
            'special'      => isset($badge['special']) && '' !== $badge['special'] ? $badge['special'] : '',
            'special_text' => isset($badge['special_text']) && '' !== $badge['special_text'] ? stripslashes($badge['special_text']) : esc_html__('Text', '^xwc'),
            'image'        => isset($badge['image']) && '' !== $badge['image'] ? $badge['image'] : '',
            'image_width'     => isset($badge['image_width']) && '' !== $badge['image_width'] ? $badge['image_width'] : 'isb_image_width_60',
        );
    }

    // Badges

    // Image badges

    // Style: Image
    function get_badge_isb_image()
    {
    ?>
        <div class="isb_sale_badge isb_image <?php echo esc_attr($this->badge['class']); ?> <?php echo esc_attr($this->badge['image_width']); ?>">
            <img src="<?php echo esc_url($this->badge['image']); ?>" alt="<?php esc_html_e('Product badge', '^xwc'); ?>" />
        </div>
    <?php
    }

    // Style: Image sale
    function get_badge_isb_image_sale()
    {
    ?>
        <div class="isb_sale_badge isb_image <?php echo esc_attr($this->badge['class']); ?> <?php echo esc_attr($this->badge['image_width']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <img src="<?php echo esc_url($this->badge['image']); ?>" alt="<?php esc_html_e('Product badge', '^xwc'); ?>" />
            <div class="isb_image_text">
                <div class="isb_sale_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </div>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Image special
    function get_badge_isb_image_special()
    {
    ?>
        <div class="isb_sale_badge isb_image <?php echo esc_attr($this->badge['class']); ?> <?php echo esc_attr($this->badge['image_width']); ?>">
            <img src="<?php echo esc_url($this->badge['image']); ?>" alt="<?php esc_html_e('Product badge', '^xwc'); ?>" />
            <div class="isb_image_text">
                <span><?php echo wp_kses_post($this->badge['special_text']); ?></span>
            </div>
        </div>
    <?php
    }

    // Sale badges

    // Style: Arraw alternative
    function get_badge_isb_style_arrow_alt()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Arrow
    function get_badge_isb_style_arrow()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('DISCOUNT', '^xwc'); ?></div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Basic alternative
    function get_badge_isb_style_basic_alt()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Basic
    function get_badge_isb_style_basic()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Border 1
    function get_badge_isb_style_border_1()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="//www.w3.org/1999/xlink">
                <polygon class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" points="0,0 200,0 200,200 0,200 " />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Border 2
    function get_badge_isb_style_border_2()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="//www.w3.org/1999/xlink">
                <polygon class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" points="100,0 121,20 150,13 158,42 187,50 180,79 200,100 180,121 187,150 158,158 150,187 121,180 100,200 79,180 50,187 42,158 13,150 20,121 0,100 20,79 13,50 42,42 50,13 79,20 " />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Border 3
    function get_badge_isb_style_border_3()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="//www.w3.org/1999/xlink">
                <path class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" d="M100 200c-62,-9 -94,-66 -100,-164l100 -36 100 36c-6,98 -38,155 -100,164z" />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Border 4
    function get_badge_isb_style_border_4()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="//www.w3.org/1999/xlink">
                <path class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" d="M100 0c-62,9 -94,66 -100,164l100 36 100 -36c-6,-98 -38,-155 -100,-164z" />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Border 5
    function get_badge_isb_style_border_5()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="//www.w3.org/1999/xlink">
                <path class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" d="M107 3l11 10c3,3 6,4 10,3l14 -4c6,-1 11,2 13,7l4 15c1,3 4,6 7,7l15 4c5,2 8,7 7,13l-4 14c-1,4 0,7 3,10l10 11c4,4 4,10 0,14l-10 11c-3,3 -4,6 -3,10l4 14c1,6 -2,11 -7,13l-15 4c-3,1 -6,4 -7,7l-4 15c-2,5 -7,8 -13,7l-14 -4c-4,-1 -7,0 -10,3l-11 10c-4,4 -10,4 -14,0l-11 -10c-3,-3 -6,-4 -10,-3l-14 4c-6,1 -11,-2 -13,-7l-4 -15c-1,-3 -4,-6 -7,-7l-15 -4c-5,-2 -8,-7 -7,-13l4 -14c1,-4 0,-7 -3,-10l-10 -11c-4,-4 -4,-10 0,-14l10 -11c3,-3 4,-6 3,-10l-4 -14c-1,-6 2,-11 7,-13l15 -4c3,-1 6,-4 7,-7l4 -15c2,-5 7,-8 13,-7l14 4c4,1 7,0 10,-3l11 -10c4,-4 10,-4 14,0z" />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Border 6
    function get_badge_isb_style_border_6()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="http://www.w3.org/1999/xlink">
                <path class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" d="M14 66l52 -52c19,-19 49,-19 68,0l52 52c19,19 19,49 0,68l-52 52c-19,19 -49,19 -68,0l-52 -52c-19,-19 -19,-49 0,-68z" />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Border 7
    function get_badge_isb_style_border_7()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="http://www.w3.org/1999/xlink">
                <polygon class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" points="100,0 106,8 113,1 118,9 126,3 130,12 138,8 141,17 150,13 151,23 161,21 161,30 171,29 170,39 179,39 177,49 187,50 183,59 192,62 188,70 197,74 191,82 199,87 192,94 200,100 192,106 199,113 191,118 197,126 188,130 192,138 183,141 187,150 177,151 179,161 170,161 171,171 161,170 161,179 151,177 150,187 141,183 138,192 130,188 126,197 118,191 113,199 106,192 100,200 94,192 87,199 82,191 74,197 70,188 62,192 59,183 50,187 49,177 39,179 39,170 29,171 30,161 21,161 23,151 13,150 17,141 8,138 12,130 3,126 9,118 1,113 8,106 0,100 8,94 1,87 9,82 3,74 12,70 8,62 17,59 13,50 23,49 21,39 30,39 29,29 39,30 39,21 49,23 50,13 59,17 62,8 70,12 74,3 82,9 87,1 94,8 " />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Border 8
    function get_badge_isb_style_border_8()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="http://www.w3.org/1999/xlink">
                <circle class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" cx="100" cy="100" r="100" />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Border 9
    function get_badge_isb_style_border_9()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive isb_group_border <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="-5 -5 210 210" xmlns:xlink="http://www.w3.org/1999/xlink">
                <circle class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" cx="100" cy="100" r="83" />
                <path class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" d="M156 14c23,29 39,163 -15,171 -53,8 -157,-85 -139,-115 18,-30 130,-84 154,-56z" />
                <path class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" d="M54 7c61,-2 123,5 138,46 14,42 -105,189 -141,135 -32,-48 -57,-178 3,-181z" />
                <path class="<?php echo esc_attr($this->badge['color']); ?> isb_stroke" d="M26 177c-26,-29 -7,-161 48,-175 55,-15 145,80 122,134 -23,54 -145,69 -170,41z" />
            </svg>
            <div class="isb_sale_percentage isb_color">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Responsive 1
    function get_badge_isb_style_responsive_1()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="0,0 200,0 200,200 0,200 " />
                    <polygon fill="#000000" fill-opacity=".05" points="200,200 0,200 200,0 " />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 2
    function get_badge_isb_style_responsive_2()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="100,0 121,20 150,13 158,42 187,50 180,79 200,100 180,121 187,150 158,158 150,187 121,180 100,200 79,180 50,187 42,158 13,150 20,121 0,100 20,79 13,50 42,42 50,13 79,20 " />
                    <polygon fill="#000000" fill-opacity=".075" points="100,0 121,20 150,13 158,42 187,50 180,79 200,100 180,121 187,150 158,158 150,187 121,180 100,200 " />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 3
    function get_badge_isb_style_responsive_3()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M100 200c-62,-9 -94,-66 -100,-164l100 -36 100 36c-6,98 -38,155 -100,164z" />
                    <path fill="#000000" fill-opacity=".075" d="M100 0l100 36c-6,98 -38,155 -100,164l0 -200z" />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 4
    function get_badge_isb_style_responsive_4()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M100 0c-62,9 -94,66 -100,164l100 36 100 -36c-6,-98 -38,-155 -100,-164z" />
                    <path fill="#000000" fill-opacity=".075" d="M100 200l100 -36c-6,-98 -38,-155 -100,-164l0 200z" />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 5
    function get_badge_isb_style_responsive_5()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M107 3l11 10c3,3 6,4 10,3l14 -4c6,-1 11,2 13,7l4 15c1,3 4,6 7,7l15 4c5,2 8,7 7,13l-4 14c-1,4 0,7 3,10l10 11c4,4 4,10 0,14l-10 11c-3,3 -4,6 -3,10l4 14c1,6 -2,11 -7,13l-15 4c-3,1 -6,4 -7,7l-4 15c-2,5 -7,8 -13,7l-14 -4c-4,-1 -7,0 -10,3l-11 10c-4,4 -10,4 -14,0l-11 -10c-3,-3 -6,-4 -10,-3l-14 4c-6,1 -11,-2 -13,-7l-4 -15c-1,-3 -4,-6 -7,-7l-15 -4c-5,-2 -8,-7 -7,-13l4 -14c1,-4 0,-7 -3,-10l-10 -11c-4,-4 -4,-10 0,-14l10 -11c3,-3 4,-6 3,-10l-4 -14c-1,-6 2,-11 7,-13l15 -4c3,-1 6,-4 7,-7l4 -15c2,-5 7,-8 13,-7l14 4c4,1 7,0 10,-3l11 -10c4,-4 10,-4 14,0z" />
                    <path fill="#000000" fill-opacity=".075" d="M107 3l11 10c3,3 6,4 10,3l14 -4c6,-1 11,2 13,7l4 15c1,3 4,6 7,7l15 4c5,2 8,7 7,13l-4 14c-1,4 0,7 3,10l10 11c4,4 4,10 0,14l-10 11c-3,3 -4,6 -3,10l4 14c1,6 -2,11 -7,13l-15 4c-3,1 -6,4 -7,7l-4 15c-2,5 -7,8 -13,7l-14 -4c-4,-1 -7,0 -10,3l-11 10c-2,2 -4,3 -7,3l0 -200c3,0 5,1 7,3z" />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 6
    function get_badge_isb_style_responsive_6()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M14 66l52 -52c19,-19 49,-19 68,0l52 52c19,19 19,49 0,68l-52 52c-19,19 -49,19 -68,0l-52 -52c-19,-19 -19,-49 0,-68z" />
                    <path fill="#000000" fill-opacity=".075" d="M100 0c12,0 25,5 34,14l52 52c19,19 19,49 0,68l-52 52c-9,9 -22,14 -34,14l0 -200z" />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 7
    function get_badge_isb_style_responsive_7()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="100,0 106,8 113,1 118,9 126,3 130,12 138,8 141,17 150,13 151,23 161,21 161,30 171,29 170,39 179,39 177,49 187,50 183,59 192,62 188,70 197,74 191,82 199,87 192,94 200,100 192,106 199,113 191,118 197,126 188,130 192,138 183,141 187,150 177,151 179,161 170,161 171,171 161,170 161,179 151,177 150,187 141,183 138,192 130,188 126,197 118,191 113,199 106,192 100,200 94,192 87,199 82,191 74,197 70,188 62,192 59,183 50,187 49,177 39,179 39,170 29,171 30,161 21,161 23,151 13,150 17,141 8,138 12,130 3,126 9,118 1,113 8,106 0,100 8,94 1,87 9,82 3,74 12,70 8,62 17,59 13,50 23,49 21,39 30,39 29,29 39,30 39,21 49,23 50,13 59,17 62,8 70,12 74,3 82,9 87,1 94,8 " />
                    <polygon fill="#000000" fill-opacity=".075" points="100,0 106,8 113,1 118,9 126,3 130,12 138,8 141,17 150,13 151,23 161,21 161,30 171,29 170,39 179,39 177,49 187,50 183,59 192,62 188,70 197,74 191,82 199,87 192,94 200,100 192,106 199,113 191,118 197,126 188,130 192,138 183,141 187,150 177,151 179,161 170,161 171,171 161,170 161,179 151,177 150,187 141,183 138,192 130,188 126,197 118,191 113,199 106,192 100,200 " />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 8
    function get_badge_isb_style_responsive_8()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <circle class="<?php echo esc_attr($this->badge['color']); ?>" cx="100" cy="100" r="100" />
                    <path fill="#000000" fill-opacity=".075" d="M100 0c55,0 100,45 100,100 0,55 -45,100 -100,100l0 -200z" />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 9
    function get_badge_isb_style_responsive_9()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <circle class="<?php echo esc_attr($this->badge['color']); ?>" cx="100" cy="100" r="83" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" fill-opacity=".6" d="M156 14c23,29 39,163 -15,171 -53,8 -157,-85 -139,-115 18,-30 130,-84 154,-56z" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" fill-opacity=".6" d="M54 7c61,-2 123,5 138,46 14,42 -105,189 -141,135 -32,-48 -57,-178 3,-181z" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" fill-opacity=".6" d="M26 177c-26,-29 -7,-161 48,-175 55,-15 145,80 122,134 -23,54 -145,69 -170,41z" />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Responsive 10
    function get_badge_isb_style_responsive_10()
    {
    ?>
        <div class="isb_sale_badge isb_group_responsive <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="//www.w3.org/2000/svg" xml:space="preserve" width="200" height="200" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 200 200" xmlns:xlink="//www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M156 14c1,2 3,4 4,6 15,8 27,18 32,33 2,7 1,16 -2,26 3,7 6,13 8,20 3,13 3,26 -2,37 -3,8 -8,15 -15,22 -5,4 -10,8 -16,11 -2,4 -5,7 -8,10 -5,3 -10,6 -16,7 -5,0 -11,0 -17,-1 -5,1 -10,3 -15,3 -2,1 -4,1 -6,1 -10,6 -19,10 -28,11 -9,1 -18,-3 -24,-11 -5,-1 -9,-2 -13,-4 -5,-2 -9,-5 -12,-8 -4,-4 -7,-10 -9,-17 -3,-13 -4,-30 -2,-49 -8,-10 -14,-21 -15,-29 0,-5 0,-9 2,-13 3,-4 8,-9 14,-15 1,0 1,0 2,-1 0,-5 1,-11 3,-15 3,-11 8,-20 16,-26 5,-3 11,-5 18,-5 2,0 5,0 7,0 4,-3 8,-4 12,-5 12,-4 27,-2 41,4 1,1 1,1 2,1 14,-2 26,-2 34,3 2,1 4,3 5,4zm32 70c-2,7 -6,15 -10,22 0,10 0,19 -2,28 -1,11 -4,20 -8,29 4,-3 7,-5 10,-8 7,-6 12,-13 15,-20 5,-10 4,-23 1,-35 -1,-5 -3,-11 -6,-16zm-72 99c-1,0 -2,0 -3,0 -1,0 -2,1 -3,2 2,-1 4,-1 6,-2zm-68 2c-10,-16 -18,-39 -24,-63 -2,-2 -4,-5 -6,-7 -1,17 0,32 3,44 1,7 4,12 7,16 3,2 7,5 11,7 3,1 6,2 9,3zm22 -178c13,-1 27,0 40,1 -13,-4 -25,-6 -35,-3 -2,0 -3,1 -5,2zm-55 99c1,-6 2,-11 3,-17 -1,-5 -1,-9 -1,-14 0,-6 0,-11 0,-17 -5,5 -9,9 -12,13 -1,3 -2,6 -1,10 1,8 5,16 11,25zm6 -28c2,-11 5,-21 9,-30 -3,2 -6,5 -9,7 -1,6 -1,13 -1,20 0,1 0,2 1,3zm12 -36c6,-12 13,-22 21,-29 1,-1 2,-2 3,-3 -1,0 -1,0 -2,0 -6,1 -12,2 -16,5 -7,5 -12,13 -15,24 -1,3 -2,7 -3,11 4,-2 8,-5 12,-8zm98 -27c12,7 24,18 35,29 -3,-8 -5,-15 -8,-21 -6,-2 -12,-5 -19,-6 -2,-1 -5,-2 -8,-2zm40 35c6,8 12,16 17,25 2,-8 2,-15 1,-20 -5,-13 -14,-23 -26,-29 3,6 6,15 8,24zm-13 123c-8,4 -16,7 -24,9 2,1 4,0 7,0 5,-1 10,-3 14,-6 1,-1 2,-2 3,-3zm-64 17c-13,2 -26,2 -38,0 5,5 12,7 19,6 6,0 12,-2 19,-6zm-41 -4c14,2 31,2 49,0 2,-1 3,-2 5,-3 1,-1 1,-1 2,-2 -10,-3 -20,-8 -30,-14 -19,-11 -36,-25 -50,-40 6,23 14,45 24,59 0,0 0,0 0,0zm71 -4c14,-4 27,-9 39,-16 5,-8 8,-20 10,-33 1,-6 1,-13 1,-21 -8,14 -18,28 -30,41 -8,10 -18,19 -27,27 2,1 5,1 7,2zm62 -102c-3,-8 -8,-15 -13,-22 1,5 2,10 2,15 2,9 2,18 3,27 3,-7 6,-14 8,-20zm-18 -28c-2,-2 -3,-4 -4,-5 -13,-14 -28,-26 -43,-34 -3,0 -6,-1 -9,-1 -8,2 -16,4 -25,7 -18,7 -36,16 -51,26 -6,12 -10,25 -13,39 -1,2 -1,4 -2,5 2,11 3,21 6,31 1,1 1,2 2,3 14,15 33,30 51,41 11,6 22,11 32,15 10,-8 20,-18 30,-28 12,-14 24,-30 32,-45 0,-11 -1,-22 -2,-32 -1,-8 -3,-16 -4,-22zm-105 -42c-2,2 -5,3 -7,5 -6,6 -12,14 -17,24 14,-9 31,-17 47,-23 5,-2 10,-4 15,-5 -12,-1 -25,-1 -38,-1zm-43 91c-1,3 -1,6 -2,9 2,2 3,3 4,5 -1,-5 -2,-9 -2,-14zm103 -91c6,1 12,2 17,3 5,2 10,3 15,5 -1,0 -1,-1 -2,-1 -1,-2 -2,-3 -4,-4 -6,-4 -15,-4 -26,-3z" />
                    <circle class="<?php echo esc_attr($this->badge['color']); ?>" cx="100" cy="100" r="83" />
                </g>
                <g>
                    <path fill="#ffffff" d="M131 129c-1,1 -3,1 -5,0 -1,-1 -1,-4 0,-5l37 -37c1,-1 4,-1 5,0 1,2 1,4 0,5l-37 37z" />
                    <path fill="#ffffff" d="M136 86c2,0 5,1 7,3 2,2 3,5 3,8 0,2 -1,5 -3,7 -2,2 -5,3 -7,3 -3,0 -6,-1 -8,-3 -2,-2 -3,-5 -3,-7 0,-3 1,-6 3,-8 2,-2 5,-3 8,-3zm2 8c-1,0 -2,-1 -2,-1 -1,0 -2,1 -3,1 0,1 -1,2 -1,3 0,0 1,1 1,2 1,0 2,1 3,1 0,0 1,-1 2,-1 0,-1 1,-2 1,-2 0,-1 -1,-2 -1,-3z" />
                    <path fill="#ffffff" d="M159 109c3,0 5,2 7,4 2,1 3,4 3,7 0,3 -1,5 -3,7 -2,2 -4,3 -7,3 -3,0 -6,-1 -8,-3 -1,-2 -3,-4 -3,-7 0,-3 2,-6 3,-7 2,-2 5,-4 8,-4zm2 8c-1,0 -1,0 -2,0 -1,0 -2,0 -3,0 0,1 -1,2 -1,3 0,1 1,1 1,2 1,1 2,1 3,1 1,0 1,0 2,-1 1,-1 1,-1 1,-2 0,-1 0,-2 -1,-3z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <?php echo esc_html($this->product['percentage']); ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Candy arrow
    function get_badge_isb_style_candy_arrow()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="92.99" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 92.99" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M6 0l54 0c3.3047,0 6,2.6953 6,6l0 54c0,1.6524 -0.6738,3.1524 -1.7607,4.2393l-26.9967 26.9964c-2.3368,2.3368 -6.1484,2.3368 -8.4852,0l-26.9885 -26.9884c-1.0917,-1.0876 -1.7689,-2.5908 -1.7689,-4.2473l0 -54c0,-3.3047 2.6953,-6 6,-6z" />
                    <path fill="#fff" fill-opacity=".1" d="M59.9966 68.4819l-22.754 22.7538c-2.3368,2.3368 -6.1484,2.3368 -8.4852,0l-22.7539 -22.7539c-2.3368,-2.3368 -2.3368,-6.1485 0,-8.4853l3.662 -3.662c12.8522,-12.8522 33.8168,-12.8522 46.669,0l3.6621 3.6621c2.3368,2.3368 2.3368,6.1485 0,8.4853z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Candy
    function get_badge_isb_style_candy()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="81.88" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 81.88" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <?php
                    if ('isb_right' === $this->badge['position']) {
                    ?>
                        <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M-0.0001 61.396l0.0001 -55.396c0,-3.3047 2.6953,-6 6,-6l54 0c3.3047,0 6,2.6953 6,6l0 69.8652c0,1.9278 -0.8181,3.5867 -2.3475,4.7602 -1.5293,1.1735 -3.3434,1.5344 -5.2055,1.0354l-54 -14.4693c-2.66,-0.7128 -4.4471,-3.0416 -4.4471,-5.7955z" />
                        <path fill="#fff" fill-opacity=".1" d="M60 0l-54 0c-3.3047,0 -6,2.6953 -6,6l0 44.9451c9.8482,2.5027 21.0779,3.9225 33,3.9225 11.9221,0 23.1518,-1.4198 33,-3.9225l0 -44.9451c0,-3.3047 -2.6953,-6 -6,-6z" />
                    <?php
                    } else {
                    ?>
                        <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M66.0001 61.396l-0.0001 -55.396c0,-3.3047 -2.6953,-6 -6,-6l-54 0c-3.3047,0 -6,2.6953 -6,6l0 69.8652c0,1.9278 0.8181,3.5867 2.3475,4.7602 1.5293,1.1735 3.3434,1.5344 5.2055,1.0354l54 -14.4693c2.66,-0.7128 4.4471,-3.0416 4.4471,-5.7955z" />
                        <path fill="#fff" fill-opacity=".1" d="M60 0l-54 0c-3.3047,0 -6,2.6953 -6,6l0 44.9451c9.8482,2.5027 21.0779,3.9225 33,3.9225 11.9221,0 23.1518,-1.4198 33,-3.9225l0 -44.9451c0,-3.3047 -2.6953,-6 -6,-6z" />
                    <?php
                    }
                    ?>
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Cloud
    function get_badge_isb_style_cloud()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="74.28" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 74.28" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <?php
                    if ('isb_right' === $this->badge['position']) {
                    ?>
                        <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M-0 50.2072c0,-12.5518 0,-25.1037 0,-37.6554 0,-6.9304 5.6214,-12.5518 12.5517,-12.5518 13.6322,0 27.2643,0 40.8965,0 6.9304,0 12.5518,5.6214 12.5518,12.5518 0,12.5517 0,25.1036 0,37.6554 0,6.9304 -5.6214,12.5518 -12.5518,12.5518 -0.2161,0 -0.4322,0 -0.6483,0l13.2001 11.519 -28.05 -11.519c-8.4661,0 -16.9322,0 -25.3983,0 -6.9303,0 -12.5517,-5.6214 -12.5517,-12.5518z" />
                        <path fill="#fff" fill-opacity=".1" d="M66 39.1058l0 11.1014c0,6.9304 -5.6214,12.5518 -12.5518,12.5518 -0.2161,0 -0.4322,0 -0.6483,0l13.2001 11.519 -28.05 -11.519c-8.4661,0 -16.9322,0 -25.3983,0 -3.3999,0 -6.4842,-1.3535 -8.7449,-3.5503 11.2968,-12.4585 30.5427,-20.6651 52.384,-20.6651 3.3369,0 6.6125,0.1932 9.8092,0.5622z" />
                    <?php
                    } else {
                    ?>
                        <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M66 50.2072c0,-12.5518 0,-25.1037 0,-37.6554 0,-6.9304 -5.6214,-12.5518 -12.5517,-12.5518 -13.6322,0 -27.2643,0 -40.8965,0 -6.9304,0 -12.5518,5.6214 -12.5518,12.5518 0,12.5517 0,25.1036 0,37.6554 0,6.9304 5.6214,12.5518 12.5518,12.5518 0.2161,0 0.4322,0 0.6483,0l-13.2001 11.519 28.05 -11.519c8.4661,0 16.9322,0 25.3983,0 6.9303,0 12.5517,-5.6214 12.5517,-12.5518z" />
                        <path fill="#fff" fill-opacity=".1" d="M-0 39.1058l0 11.1014c0,6.9304 5.6214,12.5518 12.5518,12.5518 0.2161,0 0.4322,0 0.6483,0l-13.2001 11.519 28.05 -11.519c8.4661,0 16.9322,0 25.3983,0 3.3999,0 6.4842,-1.3535 8.7449,-3.5503 -11.2968,-12.4585 -30.5427,-20.6651 -52.384,-20.6651 -3.3369,0 -6.6125,0.1932 -9.8092,0.5622z" />
                    <?php
                    }
                    ?>
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Cool
    function get_badge_isb_style_cool()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="66" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 66" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <?php
                    if ('isb_right' === $this->badge['position']) {
                    ?>
                        <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="-0,8.9999 9.8385,8.9999 16.3759,34.2407 10.9173,54.5866 62.5263,53.0978 66,2.9775 7.4436,-0.0001 " />
                        <polygon class="isb_style_cool_fill" points="-0,8.9999 9.8384,8.9999 7.4436,0 " />
                    <?php
                    } else {
                    ?>
                        <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="66,8.9999 56.1615,8.9999 49.6241,34.2407 55.0827,54.5866 3.4737,53.0978 -0,2.9775 58.5564,-0.0001 " />
                        <polygon class="isb_style_cool_fill" points="66,8.9999 56.1616,8.9999 58.5564,0 " />
                    <?php
                    }
                    ?>
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Eu 2
    function get_badge_isb_style_eu_2()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_wrap">
                <div class="isb_sale_text"><?php esc_html_e('SALE', '^xwc'); ?></div>
                <div class="isb_sale_percentage isb_color">
                    <span class="isb_percentage">
                        <?php echo esc_html($this->product['percentage']); ?>
                    </span>
                    <span class="isb_percentage_text">
                        <?php esc_html_e('%', '^xwc'); ?>
                    </span>
                </div>
            </div>
            <div class="isb_money_saved <?php echo esc_attr($this->badge['color']); ?>">
                <span class="isb_saved_old">
                    <?php echo wp_strip_all_tags(wc_price($this->product['regular'])); ?>
                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['sale'])); ?>
                </span>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Eu 3
    function get_badge_isb_style_eu_3()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_wrap">
                <div class="isb_sale_text">
                    <?php esc_html_e('SALE', '^xwc'); ?>
                    <span class="isb_sale_percentage isb_color">
                        <?php echo esc_html($this->product['percentage']); ?><?php esc_html_e('%', '^xwc'); ?>
                    </span>
                </div>
            </div>
            <div class="isb_money_saved_wrap">
                <div class="isb_money_saved <?php echo esc_attr($this->badge['color']); ?>">
                    <span class="isb_saved_old">
                        <?php echo wp_strip_all_tags(wc_price($this->product['regular'])); ?>
                    </span>
                    <span class="isb_saved">
                        <?php echo wp_strip_all_tags(wc_price($this->product['sale'])); ?>
                    </span>
                </div>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style: Eu
    function get_badge_isb_style_eu()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_wrap">
                <div class="isb_sale_text"><?php esc_html_e('SALE', '^xwc'); ?></div>
                <div class="isb_sale_percentage isb_color">
                    <span class="isb_percentage">
                        <?php echo esc_html($this->product['percentage']); ?>
                    </span>
                    <span class="isb_percentage_text">
                        <?php esc_html_e('%', '^xwc'); ?>
                    </span>
                </div>
                <div class="isb_sale_text_off"><?php esc_html_e('PRICE OFF', '^xwc'); ?></div>
            </div>
            <div class="isb_money_saved <?php echo esc_attr($this->badge['color']); ?>">
                <span class="isb_saved_old">
                    <?php echo wp_strip_all_tags(wc_price($this->product['regular'])); ?>
                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['sale'])); ?>
                </span>
            </div>
            <?php $this->print_time('text'); ?>
        </div>
    <?php
    }

    // Style Fresh 2
    function get_badge_isb_style_fresh_2()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="66" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 66" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <?php
                    if ('isb_right' === $this->badge['position']) {
                    ?>
                        <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="13.4694,0 -0,61.2856 66,47.8163 66,0 " />
                    <?php
                    } else {
                    ?>
                        <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="52.5306,0 66,61.2856 -0,47.8163 -0,0 " />
                    <?php
                    }
                    ?>
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Fresh
    function get_badge_isb_style_fresh()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="65" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 65" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <?php
                    if ('isb_right' === $this->badge['position']) {
                    ?>
                        <polygon class="isb_shadow" points="-0,5 21.982,60.6841 60,65 60,14.8506 " />
                        <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="60,36.0311 16.9053,42.8237 21.982,55.6841 60,60 " />
                        <polygon class="isb_ui" points="16.9053,42.8237 -0,0 60,9.8506 60,36.0311 " />
                    <?php
                    } else {
                    ?>
                        <polygon class="isb_shadow" points="60,5 38.018,60.6841 -0,65 -0,14.8506 " />
                        <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="-0,36.0311 43.0947,42.8237 38.018,55.6841 -0,60 " />
                        <polygon class="isb_ui" points="43.0947,42.8237 60,0 -0,9.8506 -0,36.0311 " />
                    <?php
                    }
                    ?>
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Inline
    function get_badge_isb_style_inline()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Modern
    function get_badge_isb_style_modern()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_title <?php echo esc_attr($this->badge['color']); ?>">
                <span class="isb_sale_title_text">
                    <?php esc_html_e('On Sale!', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Plain
    function get_badge_isb_style_plain()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Pop round
    function get_badge_isb_style_pop_round()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="60" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 60" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M52.6435 12.2024l0.3528 3.3739c0.0914,0.8743 0.5041,1.5919 1.2139,2.1105l2.7264 1.9918c1.0638,0.7772 1.4901,2.0913 1.0849,3.3449l-1.0457 3.2361c-0.2697,0.8346 -0.1837,1.6557 0.253,2.4163l1.6917 2.9459c0.6555,1.1418 0.5114,2.5144 -0.3669,3.4952l-2.2603 2.5242c-0.5855,0.6539 -0.84,1.4402 -0.7488,2.3132l0.3534 3.3809c0.1372,1.312 -0.554,2.511 -1.7581,3.05l-3.0693 1.3742c-0.8039,0.3599 -1.358,0.9775 -1.6288,1.8156l-1.0397 3.2174c-0.407,1.2595 -1.5311,2.0776 -2.8547,2.0776l-3.3414 0c-0.8841,0 -1.6451,0.34 -2.2349,0.9985l-2.238 2.4995c-0.8852,0.9885 -2.2496,1.279 -3.4607,0.7368l-3.0466 -1.3638c-0.8082,-0.3618 -1.6432,-0.3618 -2.4514,0l-3.0465 1.3638c-1.2111,0.5422 -2.5756,0.2517 -3.4608,-0.7369l-2.238 -2.4994c-0.5898,-0.6585 -1.3508,-0.9985 -2.2349,-0.9985l-3.3414 0c-1.3236,0 -2.4477,-0.8181 -2.8547,-2.0776l-1.0397 -3.2174c-0.2708,-0.8381 -0.8249,-1.4557 -1.6288,-1.8156l-3.0695 -1.3742c-1.204,-0.539 -1.8951,-1.738 -1.7579,-3.05l0.3534 -3.3809c0.0912,-0.873 -0.1633,-1.6593 -0.7488,-2.3132l-2.2604 -2.5242c-0.8782,-0.9808 -1.0223,-2.3534 -0.3668,-3.4951l1.6917 -2.946c0.4367,-0.7606 0.5227,-1.5817 0.253,-2.4163l-1.0457 -3.2361c-0.4051,-1.2536 0.0212,-2.5677 1.085,-3.3449l2.7263 -1.9918c0.7098,-0.5185 1.1226,-1.2362 1.214,-2.1103l0.3527 -3.3741c0.1374,-1.3142 1.0646,-2.3457 2.3567,-2.6218l3.2765 -0.7003c0.863,-0.1844 1.5351,-0.6746 1.9746,-1.4399l1.6771 -2.9208c0.6601,-1.1496 1.9324,-1.717 3.2287,-1.4399l3.2631 0.6974c0.8656,0.185 1.682,0.0108 2.3967,-0.5113l2.7004 -1.9728c1.0719,-0.783 2.4676,-0.783 3.5394,0l2.7004 1.9728c0.7147,0.5222 1.5311,0.6963 2.3967,0.5113l3.2631 -0.6974c1.2963,-0.2771 2.5687,0.2903 3.2287,1.4399l1.6771 2.9208c0.4395,0.7653 1.1116,1.2555 1.9746,1.4399l3.2765 0.7003c1.2921,0.2761 2.2193,1.3077 2.3567,2.6218z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text">
                <?php
                if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                    esc_html_e('Save', '^xwc');
                } else {
                    esc_html_e('Up to', '^xwc');
                }
                ?>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Pop
    function get_badge_isb_style_pop()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="60" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 60" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="52.4171,10.0358 53.1348,16.901 58.6888,20.9586 56.5673,27.5237 60,33.502 55.4063,38.6319 56.1239,45.4972 49.8522,48.305 47.7307,54.8701 40.8654,54.8701 36.2717,60 30,57.1924 23.7283,60 19.1346,54.8701 12.2693,54.8701 10.1478,48.305 3.8761,45.4972 4.5937,38.6319 -0,33.502 3.4327,27.5237 1.3112,20.9586 6.8652,16.901 7.5829,10.0358 14.298,8.6006 17.7307,2.6224 24.4459,4.0576 30,0 35.5541,4.0576 42.2693,2.6224 45.702,8.6006 " />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Pure
    function get_badge_isb_style_pure()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Random squares
    function get_badge_isb_style_random_squares()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="66" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 66" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <?php
                    $curr_svgs = array(
                        '3.9815,10.0087 57.0211,3.0396 64.0725,55.6403 12.5773,62.7761 ',
                        '5.4839,0.9951 57.5001,5.3141 63.7392,57.8937 2.2915,58.6448 ',
                        '12.2863,6.253 58.8568,2.6851 66,61.814 -0,47.7763 ',
                        '6.2772,5.4174 58.1691,7.6309 66,55.6662 13.7252,59.3326 ',
                    );
                    ?>
                    <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="<?php echo esc_attr($curr_svgs[array_rand($curr_svgs)]); ?>" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Ribbon
    function get_badge_isb_style_ribbon()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="0" height="60" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 60" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <?php
                    if ('isb_right' === $this->badge['position']) {
                    ?>
                        <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M60 60l-60 -60 37.7735 0 7.0024 7.0024 0 -7.0024 15.2241 0 0 15.2241 -7.0024 0 7.0024 7.0024 0 37.7735zm-9.0228 -57.1402l2.8215 0 0 2.1664 -0.5444 4.3484 -1.7437 0 -0.5334 -4.3484 0 -2.1664zm0.0974 7.1765l2.6334 0 0 2.328 -2.6334 0 0 -2.328z" />
                        <path fill="#FFFFFF" fill-opacity="0.1" d="M1.094 0l3.1045 0 55.8015 55.8015 0 3.1045 -58.906 -58.906zm4.6568 0l3.1045 0 51.1447 51.1447 0 3.1045 -54.2492 -54.2492zm4.6568 0l3.1045 0 46.4879 46.4879 0 3.1045 -49.5924 -49.5924zm4.6568 0l3.1045 0 41.8311 41.8311 0 3.1045 -44.9356 -44.9356zm4.6568 0l3.1045 0 37.1743 37.1743 0 3.1045 -40.2788 -40.2788zm4.6567 0l3.1046 0 32.5175 32.5175 0 3.1046 -35.6221 -35.6221zm4.6569 0l3.1045 0 27.8607 27.8607 0 3.1046 -30.9652 -30.9653zm4.6567 0l3.1046 0 23.2039 23.2039 0 3.1046 -26.3085 -26.3085z" />
                        <g transform="rotate(45, 33, 33)">
                            <text text-anchor="middle" transform="scale(0.99)" x="31" y="31" class="isb_sale_diff_shadow"><?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?> <?php esc_html_e('OFF', '^xwc'); ?></text>
                        </g>
                        <g transform="rotate(45, 33, 33)">
                            <text text-anchor="middle" transform="scale(0.99)" x="30" y="30" class="isb_sale_diff"><?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?> <?php esc_html_e('OFF', '^xwc'); ?></text>
                        </g>
                        <g transform="rotate(45, 40, 40)">
                            <text text-anchor="middle" transform="scale(0.99)" x="27" y="27" class="isb_sale_percentage_shadow">-<?php echo esc_html($this->product['percentage']); ?> %</text>
                        </g>
                        <g transform="rotate(45, 40, 40)">
                            <text text-anchor="middle" transform="scale(0.99)" x="26" y="26" class="isb_sale_percentage">-<?php echo esc_html($this->product['percentage']); ?> %</text>
                        </g>
                        <polygon fill="#000000" fill-opacity="0.2" points="44.7759,7.0024 52.9976,15.2241 55.5566,15.2241 44.7759,4.4434" />
                    <?php
                    } else {
                    ?>
                        <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M-0 60l60 -60 -37.7735 0 -7.0024 7.0024 0 -7.0024 -15.2241 0 0 15.2241 7.0024 0 -7.0024 7.0024 0 37.7735zm9.0228 -57.1402l-2.8215 0 0 2.1664 0.5444 4.3484 1.7437 0 0.5334 -4.3484 0 -2.1664zm-0.0974 7.1765l-2.6334 0 0 2.328 2.6334 0 0 -2.328z" />
                        <path fill="#FFFFFF" fill-opacity="0.1" d="M58.906 0l-3.1045 0 -55.8015 55.8015 0 3.1045 58.906 -58.906zm-4.6568 0l-3.1045 0 -51.1447 51.1447 0 3.1045 54.2492 -54.2492zm-4.6568 0l-3.1045 0 -46.4879 46.4879 0 3.1045 49.5924 -49.5924zm-4.6568 0l-3.1045 0 -41.8311 41.8311 0 3.1045 44.9356 -44.9356zm-4.6568 0l-3.1045 0 -37.1743 37.1743 0 3.1045 40.2788 -40.2788zm-4.6567 0l-3.1046 0 -32.5175 32.5175 0 3.1046 35.6221 -35.6221zm-4.6569 0l-3.1045 0 -27.8607 27.8607 0 3.1046 30.9652 -30.9653zm-4.6567 0l-3.1046 0 -23.2039 23.2039 0 3.1046 26.3085 -26.3085z" />
                        <g transform="rotate(-45, 0, 0)">
                            <text text-anchor="middle" transform="scale(0.99)" x="0" y="39" class="isb_sale_diff_shadow"><?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?> <?php esc_html_e('OFF', '^xwc'); ?></text>
                        </g>
                        <g transform="rotate(-45, 0, 0)">
                            <text text-anchor="middle" transform="scale(0.99)" x="0" y="38" class="isb_sale_diff"><?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?> <?php esc_html_e('OFF', '^xwc'); ?></text>
                        </g>
                        <g transform="rotate(-45, 0, 0)">
                            <text text-anchor="middle" transform="scale(0.99)" x="0" y="30" class="isb_sale_percentage_shadow">-<?php echo esc_html($this->product['percentage']); ?> %</text>
                        </g>
                        <g transform="rotate(-45, 0, 0)">
                            <text text-anchor="middle" transform="scale(0.99)" x="0" y="29" class="isb_sale_percentage">-<?php echo esc_html($this->product['percentage']); ?> %</text>
                        </g>
                        <polygon fill="#000000" fill-opacity="0.2" points="15.2241,7.0024 7.0024,15.2241 4.4434,15.2241 15.2241,4.4434 " />
                    <?php
                    }
                    ?>
                </g>
            </svg>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Round
    function get_badge_isb_style_round()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="60" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 60" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M45.6072 50.4603l5.9557 -10.9207 5.9556 -10.9211c3.3086,-6.0672 3.3088,-13.0122 0,-19.0791 -3.3087,-6.067 -8.99,-9.5394 -15.6072,-9.5394l-11.9112 0 -11.9114 0c-6.6171,0 -12.2984,3.4724 -15.607,9.5394 -3.3088,6.0671 -3.3088,13.0121 -0.0002,19.0791l5.9558 10.9211 5.9556 10.9207c3.3085,6.0669 8.9897,9.5397 15.607,9.5397 6.6174,0 12.2987,-3.4726 15.6073,-9.5397z" />
                    <path fill="#FFFFFF" fill-opacity="0.2" d="M45.6072 50.4603l5.9557 -10.9207 5.9556 -10.9211c3.3086,-6.0672 3.3088,-13.0122 0,-19.0791 -1.3601,-2.4939 -3.1213,-4.5489 -5.1834,-6.105 -17.9885,10.6546 -31.4482,28.1512 -36.7851,48.9051 3.3934,4.8993 8.5495,7.6605 14.4499,7.6605 6.6174,0 12.2987,-3.4726 15.6073,-9.5397z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: ShopKit
    function get_badge_isb_style_shopkit()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="60" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 60" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M45.6072 50.4603l5.9557 -10.9207 5.9556 -10.9211c3.3086,-6.0672 3.3088,-13.0122 0,-19.0791 -3.3087,-6.067 -8.99,-9.5394 -15.6072,-9.5394l-11.9112 0 -11.9114 0c-6.6171,0 -12.2984,3.4724 -15.607,9.5394 -3.3088,6.0671 -3.3088,13.0121 -0.0002,19.0791l5.9558 10.9211 5.9556 10.9207c3.3085,6.0669 8.9897,9.5397 15.607,9.5397 6.6174,0 12.2987,-3.4726 15.6073,-9.5397z" />
                    <path fill="#FFFFFF" fill-opacity="0.2" d="M45.6072 50.4603l5.9557 -10.9207 5.9556 -10.9211c3.3086,-6.0672 3.3088,-13.0122 0,-19.0791 -1.3601,-2.4939 -3.1213,-4.5489 -5.1834,-6.105 -17.9885,10.6546 -31.4482,28.1512 -36.7851,48.9051 3.3934,4.8993 8.5495,7.6605 14.4499,7.6605 6.6174,0 12.2987,-3.4726 15.6073,-9.5397z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Tag
    function get_badge_isb_style_tag()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="60" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 60" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <path fill="#000000" fill-opacity="0.45" d="M45.4386 15.3182l-0.0092 41.5326c-0.0004,1.7349 -1.4156,3.1495 -3.1506,3.1491l-25.1987 -0.0056c-1.735,-0.0004 -3.1496,-1.4158 -3.149,-3.1507l0.0091 -41.5325c0.0002,-0.9162 0.3476,-1.7047 1.0237,-2.3232l12.602 -11.5296c1.2079,-1.1051 3.0458,-1.1047 4.2532,0.001l12.5968 11.5352c0.6758,0.6188 1.0229,1.4074 1.0227,2.3237zm-15.7468 -10.6089c1.3045,0.0003 2.3621,1.0584 2.3618,2.3629 -0.0003,1.3045 -1.0584,2.3622 -2.3629,2.3619 -1.3045,-0.0003 -2.3621,-1.0584 -2.3618,-2.3629 0.0002,-1.3046 1.0584,-2.3622 2.3629,-2.3619z" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M46.0688 14.6884l-0.0093 41.5326c-0.0004,1.7349 -1.4156,3.1495 -3.1505,3.1491l-25.1988 -0.0056c-1.735,-0.0004 -3.1496,-1.4158 -3.149,-3.1507l0.0091 -41.5325c0.0002,-0.9163 0.3476,-1.7048 1.0237,-2.3232l12.602 -11.5296c1.2079,-1.1052 3.0458,-1.1047 4.2532,0.001l12.5968 11.5351c0.6759,0.6188 1.023,1.4075 1.0228,2.3238zm-15.7469 -10.6089c1.3045,0.0003 2.3621,1.0584 2.3618,2.3629 -0.0003,1.3045 -1.0584,2.3621 -2.3629,2.3618 -1.3045,-0.0003 -2.3621,-1.0584 -2.3618,-2.3629 0.0003,-1.3045 1.0584,-2.3621 2.3629,-2.3618z" />
                    <path fill="#000000" fill-opacity="0.3" d="M16.83 38.0625l26.34 0c0.1818,0 0.33,0.1482 0.33,0.33l0 0.34c0,0.1818 -0.1482,0.33 -0.33,0.33l-26.34 0c-0.1818,0 -0.33,-0.1482 -0.33,-0.33l0 -0.34c0,-0.1818 0.1482,-0.33 0.33,-0.33z" />
                </g>
            </svg>
            <div class="isb_sale_text"><?php esc_html_e('ON SALE', '^xwc'); ?></div>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Transparent 2
    function get_badge_isb_style_transparent_2()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Transparent
    function get_badge_isb_style_transparent()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_title <?php echo esc_attr($this->badge['color']); ?>">
                <span class="isb_sale_title_text">
                    <?php esc_html_e('On Sale!', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('OFF', '^xwc'); ?></div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Triangle
    function get_badge_isb_style_triangle()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="66" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 66" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <?php
                    if ('isb_right' === $this->badge['position']) {
                    ?>
                        <polygon class="isb_style_triangle_fill" points="2.0782,0 54.3615,66 60.2704,0 " />
                        <polygon class="<?php echo esc_attr($this->badge['color']); ?>" class="isb_style_triangle_fill" points="2.0782,0 66,63.9217 60.2704,0 " />
                    <?php
                    } else {
                    ?>
                        <polygon class="isb_style_triangle_fill" points="63.9218,0 11.6385,66 5.7296,0 " />
                        <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="63.9218,0 -0,63.9217 5.7296,0 " />
                    <?php
                    }
                    ?>
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Valentine
    function get_badge_isb_style_valentine()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="66" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 66" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" class="fil0" d="M36.4406 42.9678l-2.3664 -3.6422c-8.3648,-13.2698 -13.9892,-21.7957 -11.7611,-30.1109 1.8104,-6.7565 8.3997,-10.5608 15.0522,-8.7783 3.8458,1.0305 6.9066,3.7441 8.5447,7.1912 3.143,-2.166 7.1496,-2.9859 10.9955,-1.9554 6.6525,1.7826 10.4569,8.3719 8.6465,15.1283 -2.2281,8.3153 -11.3625,12.8856 -25.2409,20.1963l-3.8705 1.971z" />
                    <path class="isb_style_valentine_fill" d="M36.3658 42.8528l-2.2916 -3.5273c-7.0834,-11.2371 -12.201,-19.0722 -12.2498,-26.2585 0.3686,0.2065 0.728,0.4304 1.0767,0.6708 1.639,-3.4474 4.6988,-6.1608 8.5448,-7.1913 6.6525,-1.7824 13.2418,2.0219 15.0521,8.7782 2.0801,7.763 -2.685,15.7092 -10.1322,27.5281z" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M29.5593 51.8892l-3.8705 -1.9711c-13.879,-7.3096 -23.0128,-11.881 -25.2409,-20.1962 -1.8103,-6.7565 1.994,-13.3458 8.6465,-15.1283 3.8459,-1.0305 7.8533,-0.2108 10.9955,1.9554 1.639,-3.4474 4.6989,-6.1607 8.5447,-7.1912 6.6526,-1.7826 13.2419,2.0218 15.0522,8.7782 2.2281,8.3153 -3.3974,16.8405 -11.7611,30.1109l-2.3664 3.6423z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_money_saved">
                <span class="isb_saved_text">
                    <?php
                    if ('simple' === $this->product['type'] || is_singular('product') && 0 !== $this->product['id']) {
                        esc_html_e('Save', '^xwc');
                    } else {
                        esc_html_e('Up to', '^xwc');
                    }
                    ?>

                </span>
                <span class="isb_saved">
                    <?php echo wp_strip_all_tags(wc_price($this->product['difference'])); ?>
                </span>
            </div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Vintage
    function get_badge_isb_style_vintage()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <div class="isb_sale_text"><?php esc_html_e('SALE', '^xwc'); ?></div>
            <div class="isb_sale_percentage isb_color">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('PRICE OFF', '^xwc'); ?></div>
            <div class="isb_money_saved">
                <span class="isb_saved_old">
                    <?php echo wp_strip_all_tags(wc_price($this->product['regular'])); ?>
                </span>
                <span class="isb_saved isb_color">
                    <?php echo wp_strip_all_tags(wc_price($this->product['sale'])); ?>
                </span>
            </div>
            <?php $this->print_time('inherit'); ?>
        </div>
    <?php
    }

    // Style: Xmas 1
    function get_badge_isb_style_xmas_1()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>" data-id="<?php echo esc_attr($this->product['id']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="70" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 70" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <rect class="<?php echo esc_attr($this->badge['color']); ?>" width="60" height="70" />
                    <path class="isb_white" d="M5.2262 61.3079l0 0 0 4.2655 -3.6816 2.1325 -1.5446 -0.8913 0 1.3954 0.9974 0.5782c0,0.1675 0.0148,0.3352 0.0148,0.5024 -0.27,0.0707 -0.6212,0.2045 -1.0122,0.4018l0 0.3076 1.0018 0 0.0104 -0.0084 0.0003 0.0084 0.9737 0 0 -0.0084 0.011 0.0084 1.5547 0c-0.064,-0.0389 -0.1297,-0.0775 -0.1969,-0.1157 -0.5171,-0.3045 -1.004,-0.502 -1.354,-0.5937 0.0001,-0.1517 0,-0.3045 0,-0.4575l3.9092 -2.2544c0.1369,0.0615 0.2741,0.1373 0.3958,0.2132 -0.0914,0.3502 -0.1524,0.884 -0.1524,1.4778 -0.0113,0.7779 0.094,1.4392 0.2421,1.7303l0.3499 0c0.1533,-0.2927 0.2603,-0.9583 0.2603,-1.7303 0,-0.4266 -0.0307,-0.8227 -0.0917,-1.1275 0.4565,0.2444 0.8823,0.4723 1.2933,0.701 -0.0521,0.4685 -0.0376,1.247 0.0432,2.1568l0.8502 0c-0.1015,-0.7418 -0.2312,-1.3966 -0.3611,-1.852 0.5779,0.3044 1.1254,0.6092 1.6429,0.8837 -0.0425,0.2287 -0.0614,0.5653 -0.0516,0.9683l0.7803 0c-0.0524,-0.2568 -0.1094,-0.4865 -0.1664,-0.6794 0.4693,0.249 0.9037,0.4763 1.2983,0.6794l1.112 0c-0.5461,-0.3656 -1.2361,-0.8103 -2.0452,-1.3187 0.4262,-0.0917 0.9889,-0.2748 1.5819,-0.5333 1.2016,-0.5179 2.0839,-1.0972 1.9928,-1.3258 -0.0913,-0.2131 -1.1253,0.0311 -2.3276,0.5334 -0.7905,0.3358 -1.4598,0.7165 -1.7794,0.991 -0.502,-0.3049 -1.0192,-0.6252 -1.5815,-0.9755 0.5324,-0.1372 1.3077,-0.4117 2.1294,-0.7768 1.5363,-0.6707 2.7072,-1.3871 2.6162,-1.6146 -0.0914,-0.2142 -1.4147,0.1517 -2.951,0.8223 -1.0343,0.4565 -1.8863,0.9296 -2.3121,1.2488 -0.4106,-0.2435 -0.8365,-0.5023 -1.2778,-0.7613 0.3041,-0.1069 0.6541,-0.2741 1.0344,-0.503 0.8974,-0.5179 1.5363,-1.1116 1.4146,-1.3103 -0.1213,-0.2131 -0.943,0.0459 -1.856,0.5793 -0.5016,0.3047 -0.9274,0.6248 -1.1864,0.8837 -0.1213,-0.0769 -0.2434,-0.1527 -0.3799,-0.2286l0 -4.54c0.1365,-0.0769 0.2586,-0.1526 0.3799,-0.213 0.259,0.259 0.6848,0.5782 1.1864,0.8682 0.913,0.5334 1.7346,0.7924 1.856,0.5782 0.1217,-0.1975 -0.5172,-0.7913 -1.4146,-1.3102 -0.3803,-0.228 -0.7303,-0.3951 -1.0344,-0.5023 0.4414,-0.2587 0.8671,-0.5179 1.2778,-0.762 0.4258,0.3203 1.2777,0.7923 2.3121,1.2498 1.5363,0.6696 2.8596,1.0355 2.951,0.8224 0.091,-0.2132 -1.0799,-0.9441 -2.6162,-1.6147 -0.8216,-0.3662 -1.5822,-0.6396 -2.1294,-0.7768 0.5623,-0.3359 1.0795,-0.6706 1.5815,-0.9754 0.3196,0.2744 0.9888,0.6551 1.7794,0.9899l0 -0.0001c1.2023,0.5179 2.2363,0.7465 2.3276,0.5334 0.0911,-0.2286 -0.7912,-0.8067 -1.9928,-1.3257 -0.593,-0.2589 -1.1557,-0.4406 -1.5819,-0.5323 2.206,-1.3872 3.5289,-2.3012 3.453,-2.4226 -0.0606,-0.1217 -1.5211,0.5634 -3.8181,1.7819 0.1217,-0.4106 0.2434,-0.9895 0.32,-1.645 0.1517,-1.2944 0.0906,-2.3611 -0.1376,-2.3915 -0.2282,-0.031 -0.5472,1.0058 -0.7147,2.2846 -0.1065,0.8682 -0.1066,1.6306 -0.03,2.0423 -0.5175,0.2733 -1.065,0.5782 -1.6429,0.8826 0.1521,-0.5324 0.3041,-1.3402 0.4106,-2.2387 0.1824,-1.6606 0.1369,-3.0318 -0.0913,-3.0621 -0.2434,-0.0315 -0.5779,1.2947 -0.761,2.9707 -0.1213,1.1116 -0.1517,2.0871 -0.0906,2.6349 -0.411,0.2285 -0.8368,0.4576 -1.2933,0.7165 0.061,-0.3204 0.0917,-0.7165 0.0917,-1.143 0,-1.0513 -0.1983,-1.8891 -0.4417,-1.8891 -0.2282,0 -0.4258,0.8378 -0.4106,1.8891 0,0.5947 0.061,1.1275 0.1524,1.4778 -0.1217,0.0768 -0.2589,0.1527 -0.3958,0.2286l-3.9091 -2.2543c0,-0.1672 -0.0001,-0.3203 -0.0001,-0.472 0.35,-0.0918 0.8368,-0.29 1.354,-0.5948 0.9127,-0.5179 1.5515,-1.0971 1.4298,-1.3102 -0.1217,-0.1975 -0.943,0.0459 -1.8556,0.5638 -0.3651,0.213 -0.6847,0.4416 -0.943,0.6547 0,-0.5175 -0.0151,-1.0054 -0.0307,-1.4929 0.5021,-0.1977 1.3388,-0.7155 2.2511,-1.3861 1.3388,-0.9899 2.3276,-1.9498 2.1752,-2.1484 -0.1365,-0.1828 -1.3388,0.4723 -2.692,1.463 -0.7302,0.5337 -1.3388,1.066 -1.7343,1.4622 -0.0151,-0.6552 -0.0458,-1.2792 -0.061,-1.8584 0.411,-0.1369 1.065,-0.5331 1.7494,-1.0509 1.0344,-0.7769 1.7646,-1.5692 1.6274,-1.7523 -0.1365,-0.1987 -1.0947,0.2889 -2.1445,1.0672 -0.5172,0.3958 -0.9582,0.7909 -1.2471,1.1112 -0.1069,-2.6046 -0.2283,-4.2196 -0.3803,-4.2196 -0.1372,0 -0.2741,1.5995 -0.3655,4.2196 -0.2676,-0.2968 -0.6657,-0.6576 -1.1339,-1.0237l0 1.0458c0.4415,0.2931 0.8373,0.5089 1.1187,0.6027 -0.0299,0.5792 -0.0455,1.2033 -0.0606,1.8584 -0.266,-0.2662 -0.6278,-0.5939 -1.0581,-0.9422l0 0.9863c0.4155,0.2627 0.7748,0.4597 1.0429,0.5652 0,0.4874 -0.0152,0.9754 -0.0307,1.4929 -0.243,-0.2131 -0.5623,-0.4417 -0.943,-0.6547l-0.0692 -0.0394 0 0.978c0.3909,0.1976 0.7422,0.3319 1.0122,0.4026 0,0.1672 -0.0148,0.3348 -0.0148,0.5024l-0.9974 0.5782 0 1.3947 1.5446 -0.8917 3.6816 2.1336z" />
                    <polygon class="isb_white" points="1.5446,60.3169 -0,61.2122 -0,65.6768 1.5446,66.5633 4.2373,65.0096 4.2373,61.8861 " />
                    <path class="isb_white" d="M6.2586 18.3983l0 0 -1.093 -0.638 1.093 -0.6294 0 1.2674zm-6.2586 5.009l0 -1.483 0.1392 -1.2589 -0.1392 0.0812 0 -1.3707 0.544 0.2378 0.3354 -0.1895 -0.8794 -0.5149 0 -0.8237 1.5854 0.9247 0.2583 -0.1468 0 -2.2064 -0.2583 -0.1468 -1.5854 0.9249 0 -0.8209 0.8794 -0.509 -0.3354 -0.1982 -0.544 0.2377 0 -1.3707 0.1392 0.0811 -0.1392 -1.2589 0 -1.4831 0.5352 -0.0596 0.3612 3.2413 0.336 0.1982 0.0089 -1.5344 0.7053 0 -0.0087 1.9394 0.2499 0.1466 1.9193 -1.1119 0 -0.2843 -1.6786 -0.9655 0.3441 -0.6121 1.3345 0.7587 0 -0.3881 -2.6164 -1.9308 0.413 -0.5691 2.2034 1.6206 0 -0.5515 -1.9881 -1.4915 0.4213 -0.5689 1.5668 1.1809 0 -2.0516 0.7054 0 0 2.0516 1.5668 -1.1809 0.4218 0.5689 -1.9886 1.4915 0 0.5515 2.1952 -1.6206 0.4218 0.5691 -2.617 1.9308 0 0.3881 1.3256 -0.7587 0.353 0.6121 -1.6786 0.9655 0 0.2583 1.9369 1.1211 0.2323 -0.1298 -0.0087 -1.9394 0.7059 0 0 1.5344 0.3442 -0.1982 0.3613 -3.2413 0.6972 0.0777 -0.3012 2.7239 0.4735 -0.2757 0.3013 -2.4742 0.6971 0.0864 -0.2411 1.9481 1.7734 -1.0257 0.3523 0.6119 -1.7728 1.0258 1.8075 0.7673 -0.2753 0.6465 -2.2893 -0.9739 -0.4736 0.2757 2.5046 1.0944 -0.2842 0.6468 -2.9865 -1.3015 -0.3354 0.1982 1.325 0.7673 -0.3524 0.6118 -1.6785 -0.9741 -0.2154 0.1292 0 2.2498 0.2154 0.121 1.6785 -0.9739 0.3524 0.6117 -1.325 0.7761 0.3354 0.1895 2.9865 -1.3017 0.2842 0.6465 -2.5135 1.0947 0.4825 0.2759 2.2893 -0.9741 0.2753 0.6465 -1.8075 0.7671 1.7728 1.026 -0.3523 0.612 -1.7734 -1.0258 0.2411 1.9484 -0.6971 0.0861 -0.3013 -2.474 -0.4735 -0.2759 0.3012 2.7239 -0.6972 0.0775 -0.3613 -3.2413 -0.3442 -0.1892 0 1.5342 -0.7059 -0.0088 0.0087 -1.9393 -0.2323 -0.1293 -1.9369 1.1204 0 0.2675 1.6786 0.9655 -0.353 0.6118 -1.3256 -0.7671 0 0.3879 2.617 1.9396 -0.4218 0.5688 -2.1952 -1.6291 0 0.5516 1.9886 1.5002 -0.4218 0.5598 -1.5668 -1.1808 0 2.0518 -0.7054 0 0 -2.0518 -1.5668 1.1808 -0.4213 -0.5598 1.9881 -1.5002 0 -0.5516 -2.2034 1.6291 -0.413 -0.5688 2.6164 -1.9396 0 -0.3879 -1.3345 0.7671 -0.3441 -0.6118 1.6786 -0.9655 0 -0.2934 -1.9193 -1.1033 -0.2499 0.1381 0.0087 1.9393 -0.7053 0.0088 -0.0089 -1.5342 -0.336 0.1892 -0.3612 3.2413 -0.5352 -0.0595zm4.8125 -3.7767l0 0 0 -1.2583 1.0849 0.6296 -1.0849 0.6287zm-1.7727 -0.6377l0 0 1.0673 -0.6206 0 1.2328 -1.0673 -0.6122zm-0.3441 -1.8444l0 0 1.0583 0.6118 -1.0583 0.612 0 -1.2238zm1.4114 -1.233l0 0 0 1.233 -1.0673 -0.6122 1.0673 -0.6208zm1.7903 0.6034l0 0 -1.0849 0.6296 0 -1.2588 1.0849 0.6292z" />
                    <polygon class="isb_white" points="40.2345,70 39.269,67.8072 36.7272,68.0833 38.2381,66.0183 36.7272,63.9414 39.269,64.2175 40.2998,61.8765 41.3306,64.2175 43.8715,63.9414 42.3614,66.0183 43.8715,68.0833 41.3306,67.8072 40.3651,70 41.4328,70 41.6903,69.416 42.0301,70 43.5915,70 43.1283,69.9442 42.5408,68.9237 44.7704,69.1639 45.262,69.4521 45.3206,70 49.0149,70 50.3921,69.4038 50.0088,68.5036 47.4679,69.5837 46.8083,69.2 49.649,67.9513 49.2531,67.0508 45.7537,68.5995 45.262,68.3112 43.9314,66.4985 45.1177,66.4985 46.0888,67.7953 46.868,67.2071 46.3526,66.4985 47.7309,66.4985 47.7309,65.5263 46.3526,65.5263 46.868,64.8179 46.0888,64.2297 45.1177,65.5263 43.9314,65.5263 45.262,63.7132 45.7413,63.4372 49.2418,64.9859 49.6368,64.0854 46.7959,62.825 47.4555,62.4408 49.9965,63.5333 50.3798,62.6209 48.5223,61.8287 50.9912,60.3997 50.5006,59.5474 48.0308,60.9762 48.271,58.9595 47.2998,58.851 46.9638,61.5885 46.3051,61.9726 46.6402,58.8872 45.6693,58.779 45.2497,62.5851 44.7704,62.8611 42.5408,63.1011 43.1283,62.0685 44.7343,61.8765 44.6147,60.9041 43.7519,61.0119 44.4352,59.8115 43.5839,59.3194 42.9006,60.5198 42.553,59.7153 41.6542,60.0995 42.2894,61.5765 41.6903,62.609 40.7906,60.5679 40.7906,60.0394 43.8837,57.7707 43.2962,56.9785 40.7906,58.8149 40.7906,58.0468 42.9964,56.3899 42.4089,55.6096 40.7906,56.8222 40.7906,53.9291 39.8081,53.9291 39.8081,56.8222 38.1898,55.6096 37.6024,56.3899 39.8081,58.0468 39.8081,58.8149 37.3033,56.9785 36.7272,57.7707 39.8081,60.0394 39.8081,60.544 38.897,62.609 38.3094,61.5885 38.9453,60.0995 38.0341,59.7153 37.6982,60.5198 37.0033,59.3194 36.1519,59.8115 36.8476,61.0119 35.984,60.9041 35.8645,61.8887 37.459,62.0805 38.0456,63.1011 35.8283,62.8611 35.3728,62.5967 34.9656,58.791 33.9823,58.8994 34.3304,61.9843 33.6586,61.6004 33.3349,58.8632 32.3524,58.9711 32.6041,60.9882 30.0991,59.5474 29.6075,60.3997 32.1125,61.8406 30.2426,62.6448 30.6261,63.5453 33.1678,62.4528 33.8389,62.8369 30.9858,64.0974 31.3815,64.9978 34.8934,63.4491 35.3253,63.7012 36.656,65.5263 35.4932,65.5263 34.5222,64.2297 33.743,64.8179 34.2699,65.5263 32.8679,65.5263 32.8679,66.4985 34.2699,66.4985 33.743,67.2071 34.5222,67.7953 35.4932,66.4985 36.656,66.4985 35.3253,68.3235 34.882,68.5754 31.3815,67.0389 30.9858,67.9391 33.8266,69.1878 33.1678,69.572 30.6261,68.4914 30.2426,69.3921 31.6684,70 35.3099,70 35.3728,69.4279 35.8283,69.1639 38.0456,68.9237 37.4704,69.932 36.9068,70 38.5638,70 38.897,69.416 39.1547,70 " />
                    <path class="isb_white" d="M21.3012 0l12.4731 0 0 0.8371 0 0 1.673 1.6757 2.3576 0 1.658 -1.6757 0 -0.8371 12.4724 0 0 0.2734 -2.8592 0 2.0232 1.8584 -0.8368 0.914 -3.042 -2.7724 -0.9281 0 0.6847 1.0509 -1.034 0.6858 -1.1412 -1.7367 -0.6234 0 0 2.529 -1.7646 1.7671 0.4409 0.442 2.0077 -0.4113 0.2593 1.2188 -1.217 0.2434 0.6536 0.6703 4.1071 0.1828 -0.0603 1.2495 -2.7387 -0.1221 2.0229 2.0109 -0.8817 0.8837 -2.0234 -2.026 0.1216 2.7421 -1.2471 0.061 -0.1826 -4.1133 -0.6538 -0.6552 -0.2592 1.2189 -1.2165 -0.2438 0.4262 -2.0263 -0.4413 -0.4417 -1.7794 1.7822 -2.51 0 0 0.6248 1.7187 1.1275 -0.6844 1.0512 -1.0343 -0.6858 0 0.9293 2.7682 3.0321 -0.9278 0.8375 -1.8404 -2.026 0 2.8642 -1.2468 0 0 -2.8642 -1.8411 2.026 -0.9282 -0.8375 2.7693 -3.0321 0 -0.9293 -1.0346 0.6858 -0.6848 -1.0512 1.7194 -1.1275 0 -0.6248 -2.5103 0 -1.7646 -1.7822 -0.441 0.4417 0.4106 2.0263 -1.2171 0.2438 -0.2581 -1.2189 -0.6541 0.67 -0.1979 4.1137 -1.2474 -0.0607 0.1372 -2.7428 -2.0236 2.0112 -0.8815 -0.8837 2.0221 -2.0109 -2.7376 0.1221 -0.0606 -1.2495 4.1063 -0.1828 0.6544 -0.6703 -1.2167 -0.2434 0.2589 -1.234 2.0221 0.4265 0.4417 -0.442 -1.7794 -1.7671 0 -2.529 -0.624 0 -1.1406 1.7367 -1.0347 -0.6858 0.6851 -1.0509 -0.9434 0 -3.0271 2.7724 -0.8364 -0.914 2.0231 -1.8584 -2.8596 0 0 -0.2734zm21.6295 2.2842l0 0 -1.3991 1.4016 -1.5819 -1.5695 0.7606 -0.7617 0 -1.0812 2.2204 0 0 2.0108zm-3.6961 3.702l0 0 -1.9924 0 0 -2.2239 1.0798 0 0.7455 -0.762 1.5818 1.5692 -1.4147 1.4167zm-5.2327 0l0 0 -1.4143 -1.4167 1.5819 -1.5692 0.7609 0.762 1.065 0 0 2.2239 -1.9935 0zm-3.6961 -3.702l0 0 0 -2.0108 2.2208 0 0 1.0812 0.761 0.7617 -1.5671 1.5695 -1.4147 -1.4016z" />
                    <path class="isb_white" d="M48.6252 29.4934l0 0 0.4797 -0.4805 0.5315 0.5374 -0.258 0.2531 0 0.3617 -0.7532 0 0 -0.6717zm1.2535 -1.2555l0 0 0.6761 0 0 0.7543 -0.3612 0 -0.2581 0.2583 -0.5313 -0.5373 0.4745 -0.4753zm1.7746 0l0 0 0.4746 0.4753 -0.5313 0.5322 -0.2528 -0.2532 -0.3662 0 0 -0.7543 0.6757 0zm1.2535 1.2555l0 0 0 0.6717 -0.753 0 0 -0.3617 -0.258 -0.2583 0.5314 -0.5322 0.4796 0.4805zm0 1.7774l0 0 -0.4744 0.4754 -0.5366 -0.5323 0.258 -0.2584 0 -0.3666 0.753 0 0 0.6819zm-1.2535 1.2555l0 0 -0.6757 0 0 -0.7542 0.3662 0 0.2528 -0.2584 0.5365 0.5322 -0.4798 0.4804zm-1.7746 0l0 0 -0.4797 -0.4804 0.5365 -0.5322 0.2581 0.2584 0.3612 0 0 0.7542 -0.6761 0zm-0.0772 -1.7462l0 0 0 -0.8011 0.5674 -0.5631 0.7995 0 0.5623 0.5631 0 0.8011 -0.5623 0.5682 -0.7995 0 -0.5674 -0.5682zm-1.1763 0.4907l0 0 0 -0.6819 0.7532 0 0 0.3666 0.258 0.2584 -0.5315 0.5323 -0.4797 -0.4754zm-3.0539 -0.6819l0.9698 0 -0.6861 0.6302 0.2836 0.31 1.0267 -0.9402 0.3199 0 -0.2323 0.3564 0.3509 0.2326 0.3868 -0.589 0.2117 0 0 0.8577 0.6034 0.5993 -0.1498 0.1499 -0.6858 -0.1447 -0.0878 0.4185 0.4127 0.0826 -0.222 0.2273 -1.3926 0.062 0.0205 0.4238 0.9285 -0.0414 -0.6858 0.6819 0.2989 0.2998 0.6863 -0.6821 -0.0465 0.9302 0.4231 0.0205 0.0671 -1.3951 0.2218 -0.2272 0.0876 0.4134 0.4127 -0.0827 -0.1392 -0.6872 0.1495 -0.1498 0.5985 0.6044 0.8514 0 0 0.2119 -0.5831 0.3824 0.2322 0.3565 0.3509 -0.2326 0 0.3152 -0.9393 1.0283 0.3148 0.284 0.6245 -0.6871 0 0.9714 0.4228 0 0 -0.9714 0.6242 0.6871 0.3147 -0.284 -0.9389 -1.0283 0 -0.3152 0.3508 0.2326 0.2321 -0.3565 -0.5829 -0.3824 0 -0.2119 0.8513 0 0.6035 -0.6044 0.1496 0.1498 -0.1446 0.6872 0.4127 0.0827 0.0879 -0.4134 0.2217 0.2222 0.0619 1.395 0.4229 -0.0207 -0.0412 -0.9299 0.6862 0.6871 0.2991 -0.2998 -0.6861 -0.6819 0.9288 0.0414 0.0205 -0.4238 -1.3929 -0.062 -0.2217 -0.2273 0.4128 -0.0826 -0.088 -0.4133 -0.6809 0.1395 -0.1495 -0.1499 0.5984 -0.5993 0 -0.8577 0.2114 0 0.3871 0.589 0.3506 -0.2326 -0.2321 -0.3564 0.3147 0 1.0317 0.9402 0.2838 -0.31 -0.6862 -0.6302 0.9697 0 0 -0.4238 -0.9697 0 0.6862 -0.6252 -0.2838 -0.3101 -1.0317 0.9353 -0.3147 0 0.2321 -0.3514 -0.3506 -0.2324 -0.3871 0.5838 -0.2114 0 0 -0.8474 -0.6037 -0.6045 0.1548 -0.1498 0.6809 0.1395 0.088 -0.4133 -0.4128 -0.0879 0.2217 -0.2222 1.3929 -0.0619 -0.0205 -0.4237 -0.9288 0.0413 0.6861 -0.6873 -0.2991 -0.2945 -0.6862 0.6873 0.0412 -0.93 -0.4177 -0.0207 -0.0671 1.3899 -0.2217 0.2273 -0.0879 -0.4185 -0.4127 0.0878 0.1446 0.6872 -0.1548 0.1499 -0.5983 -0.5995 -0.8513 0 0 -0.2169 0.5829 -0.3823 -0.2321 -0.3514 -0.3508 0.2326 0 -0.3205 0.9389 -1.0333 -0.3147 -0.2841 -0.6242 0.6871 0 -0.9661 -0.4228 0 0 0.9661 -0.6245 -0.6871 -0.3148 0.2841 0.9393 1.0333 0 0.3152 -0.3509 -0.2273 -0.2322 0.3514 0.5831 0.3823 0 0.2169 -0.8514 0 -0.5985 0.5995 -0.1548 -0.1499 0.1445 -0.6872 -0.4127 -0.0826 -0.0876 0.4133 -0.2218 -0.2273 -0.0671 -1.3899 -0.4231 0.0155 0.0465 0.93 -0.6863 -0.6821 -0.2989 0.2998 0.6858 0.682 -0.9285 -0.0413 -0.0205 0.4237 1.3926 0.0619 0.222 0.2274 -0.4127 0.0827 0.0878 0.4133 0.6858 -0.1395 0.1498 0.1498 -0.6034 0.6045 0 0.8474 -0.2117 0 -0.3817 -0.5838 -0.356 0.2324 0.2323 0.3514 -0.3199 0 -1.0267 -0.9353 -0.2836 0.3101 0.6861 0.6252 -0.9698 0 0 0.4238z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('SALE', '^xwc'); ?></div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }

    // Style: Xmas 2
    function get_badge_isb_style_xmas_2()
    {
    ?>
        <div class="isb_sale_badge <?php echo esc_attr($this->badge['class']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="60" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 60" xmlns:xlink="http://www.w3.org/1999/xlink">
                <g>
                    <polygon class="<?php echo esc_attr($this->badge['color']); ?>" points="60,60 -0,60 -0,0 60,0 " />
                    <path fill="#FF9933" d="M46.5419 25.5869c-1.8896,-1.6261 -0.7755,-3.7591 1.6395,-4.5404 1.9472,-0.6302 5.0628,0.8613 6.2126,1.4688 1.3113,-1.7484 2.8272,-2.8925 4.4393,-3.0972 0.3869,-0.0091 0.7766,0.0355 1.1667,0.1293l0 35.0066c-9.5248,-0.3215 -10.4717,-10.1704 -10.0062,-18.235 0.2218,-3.821 1.1374,-7.5394 2.492,-10.5191 -2.075,0.4245 -4.8277,0.7469 -5.9439,-0.213z" />
                    <path fill="#FFFFFF" d="M51.6616 49.4663c0.2685,3.5752 3.8637,6.2912 8.3384,6.5341l0 -14.4117c-4.9351,0.5698 -8.628,4.0189 -8.3384,7.8776z" />
                    <path fill="#990000" d="M56.0901 49.1337c0.1317,1.7548 1.7808,3.116 3.9099,3.4011l0 -7.4807c-2.3544,0.4576 -4.053,2.1729 -3.9099,4.0796z" />
                    <path fill="#FFFFFF" d="M57.4989 48.1582c0.0617,0.8226 0.9777,1.4258 2.0476,1.3454 0.1573,-0.0118 0.3091,-0.0379 0.4535,-0.0762l0 -2.8632c-0.2133,-0.0437 -0.4415,-0.0592 -0.6772,-0.0415 -1.07,0.0802 -1.8857,0.8126 -1.8239,1.6355z" />
                    <path fill="#FFFFFF" d="M55.2828 29.8097c0.0744,0.9906 0.5924,1.7584 1.1522,1.7164 0.5634,-0.0424 0.9617,-0.8789 0.8873,-1.8696 -0.0744,-0.9895 -0.5931,-1.7579 -1.1564,-1.7156 -0.5599,0.0419 -0.9573,0.8793 -0.8831,1.8688z" />
                    <path fill="#222222" d="M55.4717 29.3716c0.0428,0.5716 0.341,1.015 0.6638,0.9907 0.3264,-0.0244 0.5551,-0.5072 0.5122,-1.079 -0.043,-0.5717 -0.3412,-1.0149 -0.6675,-0.9904 -0.3229,0.0243 -0.5515,0.5071 -0.5085,1.0787z" />
                    <path fill="#FFFFFF" d="M57.3614 20.8723c-0.6547,-1.8281 -0.8004,-3.7587 -1.8816,-5.3181 0.0656,-0.1288 0.1025,-0.2817 0.0868,-0.4636 -0.0884,-1.0198 0.313,-1.952 0.5592,-2.9232 0.2482,-0.9818 0.1577,-1.9692 -0.2152,-2.9029 -0.4143,-1.035 -2.051,-0.4562 -1.6343,0.5856 0.5736,1.4346 -0.1532,2.8272 -0.3852,4.2725 -1.467,-0.6779 -3.3841,-0.2834 -5.0888,-0.1307 0.5597,-0.8175 1.0871,-1.645 1.3736,-2.625 0.4329,-1.4803 -0.4581,-2.8192 -1.4612,-3.8019 -0.8021,-0.7839 -1.9282,0.5366 -1.1324,1.3155 1.8008,1.7616 0.3258,3.4434 -0.8312,5.077 -1.5878,-0.202 -3.0202,-0.6237 -4.3001,-1.2548 -0.1334,-1.3991 2.2395,-3.6327 2.7451,-4.8467 0.6574,-1.5781 0.2744,-3.2615 -0.0809,-4.8571 -0.2425,-1.089 -1.8744,-0.4938 -1.6342,0.5855 0.2483,1.1119 0.4555,2.1531 0.2209,3.2844 -0.2203,1.0622 -1.0357,1.9505 -1.6767,2.7837 -0.4966,0.647 -0.964,1.3438 -1.1836,2.0915 -2.0959,-1.4807 -3.6973,-3.6197 -4.825,-6.322 -0.4282,-1.0271 -2.0661,-0.4498 -1.6343,0.5855 0.583,1.3969 1.2822,2.6997 2.1171,3.8724 -0.5341,0.0342 -1.0648,0.1189 -1.6045,0.2187 -1.021,0.189 -2.2666,0.574 -3.2193,0.0021 -0.9614,-0.5787 -1.7121,0.988 -0.7614,1.5593 2.0224,1.2149 4.3343,-0.3108 6.4679,-0.05 0.1823,0.0225 0.3407,-0.0089 0.4782,-0.0704 1.4131,1.4868 3.1397,2.6552 5.2564,3.3781 1.4832,0.5057 3.0661,0.8136 4.6482,0.8796 -0.202,0.278 -0.3937,0.5564 -0.5875,0.8036 -1.2068,1.5329 -3.8242,2.1859 -5.6779,1.9539 -1.1064,-0.1378 -1.4454,1.5652 -0.3353,1.704 1.834,0.2287 3.5692,-0.1649 5.2224,-0.9634 0.6876,-0.3322 1.3094,-0.7499 1.8573,-1.2769 0.5839,-0.5612 1.0644,-1.8886 1.8706,-2.1439 0.1475,-0.0465 0.2602,-0.1194 0.3471,-0.2068 1.8257,-0.226 3.3171,-0.1106 4.1465,1.8116 0.5452,1.2633 0.6562,2.6841 1.119,3.9785 0.3767,1.0525 2.012,0.4697 1.6343,-0.5856z" />
                </g>
            </svg>
            <div class="isb_sale_percentage">
                <span class="isb_percentage">
                    <?php echo esc_html($this->product['percentage']); ?>
                </span>
                <span class="isb_percentage_text">
                    <?php esc_html_e('%', '^xwc'); ?>
                </span>
            </div>
            <div class="isb_sale_text"><?php esc_html_e('SALE', '^xwc'); ?></div>
            <?php $this->print_time(); ?>
        </div>
    <?php
    }


    // Special badges

    // Style: Arrow
    function get_badge_isb_special_arrow()
    {
    ?>
        <div class="isb_sale_badge isb_special <?php echo esc_attr($this->badge['class']); ?>">
            <span class="isb_special_text"><?php echo wp_kses_post($this->badge['special_text']); ?></span>
        </div>
    <?php
    }

    // Style: Big badge
    function get_badge_isb_special_bigbadge()
    {
    ?>
        <div class="isb_sale_badge isb_special <?php echo esc_attr($this->badge['class']); ?>">
            <span class="isb_special_text"><?php echo wp_kses_post($this->badge['special_text']); ?></span>
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="60" height="60" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 60 60" xmlns:xlink="http://www.w3.org/1999/xlink">
                <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M52.6435 12.2024l0.3528 3.3739c0.0914,0.8743 0.5041,1.5919 1.2139,2.1105l2.7264 1.9918c1.0638,0.7772 1.4901,2.0913 1.0849,3.3449l-1.0457 3.2361c-0.2697,0.8346 -0.1837,1.6557 0.253,2.4163l1.6917 2.9459c0.6555,1.1418 0.5114,2.5144 -0.3669,3.4952l-2.2603 2.5242c-0.5855,0.6539 -0.84,1.4402 -0.7488,2.3132l0.3534 3.3809c0.1372,1.312 -0.554,2.511 -1.7581,3.05l-3.0693 1.3742c-0.8039,0.3599 -1.358,0.9775 -1.6288,1.8156l-1.0397 3.2174c-0.407,1.2595 -1.5311,2.0776 -2.8547,2.0776l-3.3414 0c-0.8841,0 -1.6451,0.34 -2.2349,0.9985l-2.238 2.4995c-0.8852,0.9885 -2.2496,1.279 -3.4607,0.7368l-3.0466 -1.3638c-0.8082,-0.3618 -1.6432,-0.3618 -2.4514,0l-3.0465 1.3638c-1.2111,0.5422 -2.5756,0.2517 -3.4608,-0.7369l-2.238 -2.4994c-0.5898,-0.6585 -1.3508,-0.9985 -2.2349,-0.9985l-3.3414 0c-1.3236,0 -2.4477,-0.8181 -2.8547,-2.0776l-1.0397 -3.2174c-0.2708,-0.8381 -0.8249,-1.4557 -1.6288,-1.8156l-3.0695 -1.3742c-1.204,-0.539 -1.8951,-1.738 -1.7579,-3.05l0.3534 -3.3809c0.0912,-0.873 -0.1633,-1.6593 -0.7488,-2.3132l-2.2604 -2.5242c-0.8782,-0.9808 -1.0223,-2.3534 -0.3668,-3.4951l1.6917 -2.946c0.4367,-0.7606 0.5227,-1.5817 0.253,-2.4163l-1.0457 -3.2361c-0.4051,-1.2536 0.0212,-2.5677 1.085,-3.3449l2.7263 -1.9918c0.7098,-0.5185 1.1226,-1.2362 1.214,-2.1103l0.3527 -3.3741c0.1374,-1.3142 1.0646,-2.3457 2.3567,-2.6218l3.2765 -0.7003c0.863,-0.1844 1.5351,-0.6746 1.9746,-1.4399l1.6771 -2.9208c0.6601,-1.1496 1.9324,-1.717 3.2287,-1.4399l3.2631 0.6974c0.8656,0.185 1.682,0.0108 2.3967,-0.5113l2.7004 -1.9728c1.0719,-0.783 2.4676,-0.783 3.5394,0l2.7004 1.9728c0.7147,0.5222 1.5311,0.6963 2.3967,0.5113l3.2631 -0.6974c1.2963,-0.2771 2.5687,0.2903 3.2287,1.4399l1.6771 2.9208c0.4395,0.7653 1.1116,1.2555 1.9746,1.4399l3.2765 0.7003c1.2921,0.2761 2.2193,1.3077 2.3567,2.6218z" />
            </svg>
        </div>
    <?php
    }

    // Style: Border round
    function get_badge_isb_special_border_round()
    {
    ?>
        <div class="isb_sale_badge isb_special <?php echo esc_attr($this->badge['class']); ?>">
            <span class="isb_special_text isb_color"><?php echo wp_kses_post($this->badge['special_text']); ?></span>
        </div>
    <?php
    }

    // Style: Border
    function get_badge_isb_special_border()
    {
    ?>
        <div class="isb_sale_badge isb_special <?php echo esc_attr($this->badge['class']); ?>">
            <span class="isb_special_text isb_color"><?php echo wp_kses_post($this->badge['special_text']); ?></span>
        </div>
    <?php
    }

    // Style: Overline
    function get_badge_isb_special_overline()
    {
    ?>
        <div class="isb_sale_badge isb_special <?php echo esc_attr($this->badge['class']); ?>">
            <span class="isb_special_text isb_color"><?php echo wp_kses_post($this->badge['special_text']); ?></span>
        </div>
    <?php
    }

    // Style: Plain
    function get_badge_isb_special_plain()
    {
    ?>
        <div class="isb_sale_badge isb_special <?php echo esc_attr($this->badge['class']); ?>">
            <span class="isb_special_text"><?php echo wp_kses_post($this->badge['special_text']); ?></span>
        </div>
    <?php
    }

    // Style: Ribbon
    function get_badge_isb_special_ribbon()
    {
    ?>
        <div class="isb_sale_badge isb_special <?php echo esc_attr($this->badge['class']); ?>">
            <svg xmlns="http://www.w3.org/2000/svg" xml:space="preserve" width="66" height="66" style="shape-rendering:geometricPrecision; text-rendering:geometricPrecision; image-rendering:optimizeQuality; fill-rule:evenodd; clip-rule:evenodd" viewBox="0 0 66 66" xmlns:xlink="http://www.w3.org/1999/xlink">
                <?php if ('isb_right' === $this->badge['position']) { ?>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M47.989 -0.0001c-9.2919,0 -18.3992,8.4642 -18.3992,17.7561 0,6.2667 1.3154,13.3257 8.212,23.5298 -7.7299,5.141 -16.0234,9.0926 -21.4826,9.2593 6.0232,3.9795 11.2062,10.7992 11.6545,15.4548 6.2808,-5.4251 11.9621,-10.5999 16.9064,-15.4932 2.1289,2.5042 4.5456,5.17 7.2894,8.0192 0.4483,-4.6556 5.6313,-11.4753 11.6545,-15.4549 -3.051,-0.0931 -6.3761,-1.0129 -9.6449,-2.4736 8.1391,-9.5103 12.5022,-17.646 11.7373,-24.0944 -1.3791,-11.6256 -8.6355,-16.5031 -17.9274,-16.5031zm-2.3329 35.488c-5.9951,-4.577 -10.4617,-10.3669 -10.4616,-14.8392 0,-8.5928 8.1486,-11.7803 12.7945,-11.7803 5.9129,0 12.2186,3.6697 9.4317,12.9402 -1.0901,3.6261 -5.7579,8.7555 -11.7646,13.6793z" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M47.9891 8.8684l0 -8.8685c-9.2919,0 -18.3994,8.4642 -18.3994,17.7561 0,9.2919 2.8899,20.3238 22.5798,40.7699 0.4482,-4.6557 5.6313,-11.4754 11.6545,-15.4549 -12.144,-0.3708 -28.6296,-13.8295 -28.6296,-22.4223 0.0001,-8.5928 8.1487,-11.7803 12.7947,-11.7803z" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M47.9891 8.8684l0 -8.8685c9.2919,0 16.5483,4.8776 17.9273,16.5031 1.379,11.6256 -13.9036,28.7327 -37.9427,49.497 -0.4482,-4.6557 -5.6313,-11.4754 -11.6545,-15.4549 12.144,-0.3708 38.3146,-19.466 41.1015,-28.7365 2.787,-9.2706 -3.5189,-12.9402 -9.4316,-12.9402z" />
                    <path class="isb_special_ribbon_fill" d="M44.8805 50.5071c2.1289,2.5042 4.5454,5.1699 7.289,8.0188 0.4483,-4.6556 5.6313,-11.4753 11.6545,-15.4549 -3.051,-0.0931 -6.3761,-1.0129 -9.6449,-2.4736 -2.7004,3.1556 -5.816,6.4625 -9.2986,9.9097z" />
                    <path id="_127794016" class="isb_special_ribbon_fill" d="M29.7715 15.4809c-0.1186,0.7499 -0.1817,1.5096 -0.1817,2.2751 0,6.2668 1.3156,13.3258 8.212,23.5298 2.739,-1.8217 5.4071,-3.792 7.8533,-5.7971 -8.3992,-3.6299 -13.3655,-13.014 -15.8836,-20.0078z" />
                    <path class="isb_special_ribbon_fill2" d="M47.989 -0.0001c8.1038,0 14.6587,3.7107 17.1175,12.3714 2.2152,9.3216 -7.5336,17.2944 -15.9456,20.0785l-0.0002 -0.0005c4.2645,-3.9247 7.3934,-7.7578 8.26,-10.6407 2.7869,-9.2705 -3.5188,-12.9402 -9.4317,-12.9402 -2.5578,0 -6.177,0.9668 -8.9139,3.2692l-0.0002 -0.0006c1.2208,-5.3189 4.581,-9.0817 8.9141,-12.1371z" />
                <?php } else { ?>
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M18.0111 -0.0001c9.2919,0 18.3992,8.4642 18.3992,17.7561 0,6.2667 -1.3154,13.3257 -8.212,23.5298 7.7299,5.141 16.0234,9.0926 21.4826,9.2593 -6.0232,3.9795 -11.2062,10.7992 -11.6545,15.4548 -6.2808,-5.4251 -11.9621,-10.5999 -16.9064,-15.4932 -2.1289,2.5042 -4.5456,5.17 -7.2894,8.0192 -0.4483,-4.6556 -5.6313,-11.4753 -11.6545,-15.4549 3.051,-0.0931 6.3761,-1.0129 9.6449,-2.4736 -8.1391,-9.5103 -12.5022,-17.646 -11.7373,-24.0944 1.3791,-11.6256 8.6355,-16.5031 17.9274,-16.5031zm2.3329 35.488c5.9951,-4.577 10.4617,-10.3669 10.4616,-14.8392 0,-8.5928 -8.1486,-11.7803 -12.7945,-11.7803 -5.9129,0 -12.2186,3.6697 -9.4317,12.9402 1.0901,3.6261 5.7579,8.7555 11.7646,13.6793z" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M18.011 8.8684l0 -8.8685c9.2919,0 18.3994,8.4642 18.3994,17.7561 0,9.2919 -2.8899,20.3238 -22.5798,40.7699 -0.4482,-4.6557 -5.6313,-11.4754 -11.6545,-15.4549 12.144,-0.3708 28.6296,-13.8295 28.6296,-22.4223 -0.0001,-8.5928 -8.1487,-11.7803 -12.7947,-11.7803z" />
                    <path class="<?php echo esc_attr($this->badge['color']); ?>" d="M18.011 8.8684l0 -8.8685c-9.2919,0 -16.5483,4.8776 -17.9273,16.5031 -1.379,11.6256 13.9036,28.7327 37.9427,49.497 0.4482,-4.6557 5.6313,-11.4754 11.6545,-15.4549 -12.144,-0.3708 -38.3146,-19.466 -41.1015,-28.7365 -2.787,-9.2706 3.5189,-12.9402 9.4316,-12.9402z" />
                    <path class="isb_special_ribbon_fill" d="M21.1196 50.5071c-2.1289,2.5042 -4.5454,5.1699 -7.289,8.0188 -0.4483,-4.6556 -5.6313,-11.4753 -11.6545,-15.4549 3.051,-0.0931 6.3761,-1.0129 9.6449,-2.4736 2.7004,3.1556 5.816,6.4625 9.2986,9.9097z" />
                    <path class="isb_special_ribbon_fill" d="M36.2286 15.4809c0.1186,0.7499 0.1817,1.5096 0.1817,2.2751 0,6.2668 -1.3156,13.3258 -8.212,23.5298 -2.739,-1.8217 -5.4071,-3.792 -7.8533,-5.7971 8.3992,-3.6299 13.3655,-13.014 15.8836,-20.0078z" />
                    <path class="isb_special_ribbon_fill2" d="M18.0111 -0.0001c-8.1038,0 -14.6587,3.7107 -17.1175,12.3714 -2.2152,9.3216 7.5336,17.2944 15.9456,20.0785l0.0002 -0.0005c-4.2645,-3.9247 -7.3934,-7.7578 -8.26,-10.6407 -2.7869,-9.2705 3.5188,-12.9402 9.4317,-12.9402 2.5578,0 6.177,0.9668 8.9139,3.2692l0.0002 -0.0006c-1.2208,-5.3189 -4.581,-9.0817 -8.9141,-12.1371z" />
                <?php
                }
                ?>
            </svg>
            <span class="isb_special_text isb_color"><?php echo wp_kses_post($this->badge['special_text']); ?></span>
        </div>
    <?php
    }

    // Style: Underline
    function get_badge_isb_special_underline()
    {
    ?>
        <div class="isb_sale_badge isb_special <?php echo esc_attr($this->badge['class']); ?>">
            <span class="isb_special_text isb_color"><?php echo wp_kses_post($this->badge['special_text']); ?></span>
        </div>
<?php
    }
}
add_action('init', array('XforWC_Improved_Badges_GetBadge', 'instance'));

function XforWC_Improved_Badges_GetBadge()
{
    return XforWC_Improved_Badges_GetBadge::instance();
}
