<?php

if (!defined('ABSPATH')) {
	exit;
}

class XforWC_Improved_Badges_Settings
{

	public static $presets;
	public static $isb_style;
	public static $isb_style_special;
	public static $isb_color;
	public static $isb_position;

	public static $plugin;

	public static function init()
	{
		self::$plugin = array(
			'name'    => 'Improved Badges for WooCommerce',
			'xforwc'  => 'Badges and Counters',
			'slug'    => 'product-badges',
			'label'   => 'improved_badges',
			'image'   => ImprovedBadges()->plugin_url() . '/assets/images/improved-badges-for-woocommerce-elements.png',
			'path'    => 'improved-sale-badges/improved-sale-badges',
			'version' => XforWC_Improved_Badges::$version,
		);

		include_once 'isb-badges.php';

		if (SevenVXGet()->plugin_page_check(self::$plugin['label'])) {
			add_action('svx_plugins_settings', array('XforWC_Improved_Badges_Settings', 'get_settings'), 50);
		}

		if (function_exists('XforWC')) {
			add_filter('xforwc_settings', array('XforWC_Improved_Badges_Settings', 'xforwc'), 9999999121);
			add_filter('xforwc_svx_get_product_badges', array('XforWC_Improved_Badges_Settings', '_get_settings_xforwc'));
		}

		add_filter('svx_plugins', array('XforWC_Improved_Badges_Settings', 'add_plugin'), 0);

		add_action('admin_enqueue_scripts', __CLASS__ . '::isb_scripts', 9);
		add_action('wp_ajax_isb_respond', __CLASS__ . '::isb_respond');
	}

	public static function xforwc($settings)
	{
		$settings['plugins'][] = self::$plugin;

		return $settings;
	}

	public static function add_plugin($plugins)
	{
		$plugins[self::$plugin['label']] = array(
			'slug' => self::$plugin['label'],
			'name' => self::$plugin['xforwc'],
		);

		return $plugins;
	}

	public static function _get_settings_xforwc()
	{
		$settings = self::get_settings(array());
		return $settings[self::$plugin['label']];
	}

	public static function isb_scripts($hook)
	{

		$init = false;

		if (SevenVXGet()->plugin_page_check(self::$plugin['label'])) {
			$init = true;
		}

		if (SevenVXGet()->xforwoo_page_check()) {
			$init = true;
		}

		if ('post-new.php' === $hook || 'post.php' === $hook) {
			$init = true;
		}

		if (true === $init) {
			wp_enqueue_style('isb-style', ImprovedBadges()->plugin_url() . '/assets/css/admin' . (is_rtl() ? '-rtl' : '') . '.css', false, XforWC_Improved_Badges::$version);
			wp_enqueue_style('isb-css-style', ImprovedBadges()->plugin_url() . '/assets/css/styles' . (is_rtl() ? '-rtl' : '') . '.css', false, XforWC_Improved_Badges::$version);

			wp_enqueue_script('isb-admin', ImprovedBadges()->plugin_url() . '/assets/js/admin.js', array('jquery'), XforWC_Improved_Badges::$version, true);

			$curr_args = array(
				'ajax' => admin_url('admin-ajax.php'),
			);

			wp_localize_script('isb-admin', 'isb', $curr_args);
		}
	}

	public static function _get_setting_preview()
	{
		return array(
			'name'  => esc_html__('Preview', '^xwc'),
			'type'  => 'hidden',
			'desc'  => esc_html__('Current badge preview', '^xwc'),
			'id'    => 'preview',
			'class' => 'isb_preview',
		);
	}

	public static function _get_setting_name()
	{
		return array(
			'name'    => esc_html__('Preset Name', '^xwc'),
			'type'    => 'text',
			'id'      => 'name',
			'desc'    => esc_html__('Enter preset name', '^xwc'),
			'default' => '',
		);
	}
	public static function _get_setting_style()
	{
		return array(
			'name'    => esc_html__('Style', '^xwc'),
			'type'    => 'select',
			'desc'    => esc_html__('Select badge style', '^xwc'),
			'id'      => 'style',
			'default' => 'isb_style_shopkit',
			'options' => self::$isb_style,
		);
	}
	public static function _get_setting_color()
	{
		return array(
			'name'    => esc_html__('Color', '^xwc'),
			'type'    => 'select',
			'desc'    => esc_html__('Select badge color', '^xwc'),
			'id'      => 'color',
			'default' => 'isb_sk_material',
			'options' => self::$isb_color,
		);
	}
	public static function _get_setting_position()
	{
		return array(
			'name'    => esc_html__('Position', '^xwc'),
			'type'    => 'select',
			'desc'    => esc_html__('Select badge position', '^xwc'),
			'id'      => 'position',
			'default' => 'isb_left',
			'options' => self::$isb_position,
		);
	}
	public static function _get_setting_special()
	{
		return array(
			'name'    => esc_html__('Style', '^xwc'),
			'type'    => 'select',
			'desc'    => esc_html__('Select badge style', '^xwc'),
			'id'      => 'special',
			'default' => '',
			'options' => self::$isb_style_special,
		);
	}
	public static function _get_setting_special_text()
	{
		return array(
			'name'    => esc_html__('Special Text', '^xwc'),
			'type'    => 'textarea',
			'desc'    => esc_html__('Enter badge text', '^xwc'),
			'id'      => 'special_text',
			'default' => 'Text',
		);
	}
	public static function _get_setting_image()
	{
		return array(
			'name'    => esc_html__('Image', '^xwc'),
			'type'    => 'file',
			'desc'    => esc_html__('Set image', '^xwc'),
			'id'      => 'image',
			'default' => '',
		);
	}
	public static function _get_setting_image_width()
	{
		return array(
			'name'    => esc_html__('Image Width', '^xwc'),
			'type'    => 'select',
			'desc'    => esc_html__('Set image width', '^xwc'),
			'id'      => 'image_width',
			'default' => 'isb_image_width_60',
			'options' => array(
				'isb_image_width_30' => '30px',
				'isb_image_width_40' => '40px',
				'isb_image_width_50' => '50px',
				'isb_image_width_60' => '60px',
				'isb_image_width_70' => '70px',
				'isb_image_width_80' => '80px',
				'isb_image_width_90' => '90px',
				'isb_image_width_100' => '100px',
				'isb_image_width_110' => '110px',
				'isb_image_width_120' => '120px',
			),
		);
	}

	public static function get_settings($plugins)
	{

		$plugins[self::$plugin['label']] = array(
			'slug'     => self::$plugin['label'],
			'name'     => esc_html(function_exists('XforWC') ? self::$plugin['xforwc'] : self::$plugin['name']),
			'desc'     => esc_html(function_exists('XforWC') ? self::$plugin['name'] . ' v' . self::$plugin['version'] : esc_html__('Settings page for', '^xwc') . ' ' . self::$plugin['name']),
			'link'     => esc_url('https://xforwoocommerce.com/store/badges-and-counters/'),
			'ref'      => array(
				'name' => esc_html__('Visit XforWooCommerce.com', '^xwc'),
				'url'  => 'https://xforwoocommerce.com',
			),
			'doc'      => array(
				'name' => esc_html__('Get help', '^xwc'),
				'url'  => 'https://help.xforwoocommerce.com',
			),
			'sections' => array(
				'dashboard'    => array(
					'name' => esc_html__('Dashboard', '^xwc'),
					'desc' => esc_html__('Dashboard Overview', '^xwc'),
				),
				'presets'      => array(
					'name' => esc_html__('Badge Presets', '^xwc'),
					'desc' => esc_html__('Badge Presets Options', '^xwc'),
				),
				'manager'      => array(
					'name' => esc_html__('Badge Manager', '^xwc'),
					'desc' => esc_html__('Manager Options', '^xwc'),
				),
				'extra'       => array(
					'name' => esc_html__('Extras', '^xwc'),
					'desc' => esc_html__('Extra Options', '^xwc'),
				),
				'installation' => array(
					'name' => esc_html__('Installation', '^xwc'),
					'desc' => esc_html__('Installation Options', '^xwc'),
				),
			),
			'settings' => array(

				'wcmn_dashboard'                     => array(
					'type'    => 'html',
					'id'      => 'wcmn_dashboard',
					'desc'    => '
						<h3><span class="dashicons dashicons-store"></span> XforWooCommerce</h3>
						<p>' . esc_html__('Visit XforWooCommerce.com store, demos and knowledge base.', '^xwc') . '</p>
						<p><a href="https://xforwoocommerce.com" class="xforwc-button-primary x-color" target="_blank">XforWooCommerce.com</a></p>

						<br /><hr />

						<h3><span class="dashicons dashicons-admin-tools"></span> ' . esc_html__('Help Center', '^xwc') . '</h3>
						<p>' . esc_html__('Need support? Visit the Help Center.', '^xwc') . '</p>
						<p><a href="https://help.xforwoocommerce.com" class="xforwc-button-primary red" target="_blank">XforWooCommerce.com HELP</a></p>
						
						<br /><hr />

						<h3><span class="dashicons dashicons-update"></span> ' . esc_html__('Automatic Updates', '^xwc') . '</h3>
						<p>' . esc_html__('Get automatic updates, by downloading and installing the Envato Market plugin.', '^xwc') . '</p>
						<p><a href="https://envato.com/market-plugin/" class="svx-button" target="_blank">Envato Market Plugin</a></p>
						
						<br />',
					'section' => 'dashboard',
				),

				'wcmn_utility'                       => array(
					'name'    => esc_html__('Plugin Options', '^xwc'),
					'type'    => 'utility',
					'id'      => 'wcmn_utility',
					'desc'    => esc_html__('Quick export/import, backup and restore, or just reset your optons here', '^xwc'),
					'section' => 'dashboard',
				),

				'wcmn_isb_presets'                   => array(
					'name'         => esc_html__('Presets Manager', '^xwc'),
					'type'         => 'list-select',
					'id'           => 'wcmn_isb_presets',
					'desc'         => esc_html__('Add badge presets using the Presets Manager', '^xwc'),
					'autoload'     => false,
					'section'      => 'presets',
					'title'        => esc_html__('Preset Name', '^xwc'),
					'options'      => 'list',
					'ajax_options' => 'ajax:wp_options:_wcmn_isb_preset_%NAME%',
					'selects'      => array(
						'sale'          => esc_html__('Sale', '^xwc'),
						'special'       => esc_html__('Text', '^xwc'),
						'image'         => esc_html__('Image', '^xwc'),
						'image-sale'    => esc_html__('Image sale', '^xwc'),
						'image-special' => esc_html__('Image text', '^xwc'),
					),
					'settings'     => array(
						'sale'          => array(
							'preview'  => self::_get_setting_preview(),
							'name'     => self::_get_setting_name(),
							'style'    => self::_get_setting_style(),
							'color'    => self::_get_setting_color(),
							'position' => self::_get_setting_position(),
						),
						'special'       => array(
							'preview'      => self::_get_setting_preview(),
							'name'         => self::_get_setting_name(),
							'special'      => self::_get_setting_special(),
							'special_text' => self::_get_setting_special_text(),
							'color'        => self::_get_setting_color(),
							'position'     => self::_get_setting_position(),
						),
						'image'         => array(
							'preview'  => self::_get_setting_preview(),
							'name'     => self::_get_setting_name(),
							'image'    => self::_get_setting_image(),
							'image_width'    => self::_get_setting_image_width(),
							'position' => self::_get_setting_position(),
						),
						'image-sale'    => array(
							'preview'  => self::_get_setting_preview(),
							'name'     => self::_get_setting_name(),
							'image'    => self::_get_setting_image(),
							'image_width'    => self::_get_setting_image_width(),
							'position' => self::_get_setting_position(),
						),
						'image-special' => array(
							'preview'      => self::_get_setting_preview(),
							'name'         => self::_get_setting_name(),
							'image'        => self::_get_setting_image(),
							'position'     => self::_get_setting_position(),
							'image_width'    => self::_get_setting_image_width(),
							'special_text' => self::_get_setting_special_text(),
						),
					),
				),

				'overrides_notice'          => array(
					'name'    => esc_html__('Badge Overrides', '^xwc'),
					'type'    => 'html',
					'desc'    => '
					<div class="svx-option-header"><h3>' . esc_html__('Badge Overrides', '^xwc') . '</h3></div><div class="svx-option-wrapper"><div class="svx-notice svx-info">' . esc_html__('.', '^xwc') . '</div></div>',
					'section' => 'integration',
					'id'      => 'widget_notice',
				),

				'wcmn_isb_addons'                 => array(
					'name'     => esc_html__('Badge Addons', '^xwc'),
					'type'     => 'hidden',
					'id'       => 'wcmn_isb_addons',
					'desc'     => esc_html__('Set badge addons', '^xwc'),
					'autoload' => false,
					'section'  => 'hidden',
				),

				'wcmn_isb_overrides'                 => array(
					'name'     => esc_html__('Badge Overrides', '^xwc'),
					'type'     => 'hidden',
					'id'       => 'wcmn_isb_overrides',
					'desc'     => esc_html__('Set badge overrides', '^xwc'),
					'autoload' => false,
					'section'  => 'hidden',
				),

				'primary_badge'                   => array(
					'name'     => esc_html__('Primary Badge', '^xwc'),
					'type'     => 'multiselect',
					'id'       => 'primary_badge',
					'desc'     => esc_html__('Set primary badge (optional). Primary badge is shown on all products. If it is a sale badge, it will show only on discounted products', '^xwc'),
					'autoload' => false,
					'section'  => 'manager',
					'options'  => 'read:wcmn_isb_presets',
					'class'    => 'svx-selectize',
				),

				'isb_addons_notice'          => array(
					'name'    => esc_html__('Badge Addons', '^xwc'),
					'type'    => 'html',
					'desc'    => '
					<div class="svx-option-header"><h3>' . esc_html__('Badge Addons', '^xwc') . '</h3></div><div class="svx-option-wrapper"><div class="svx-notice svx-info">' . esc_html__('Badge addons are used to add a badge on top of the other badges.', '^xwc') . '</div></div>',
					'section' => 'manager',
					'id'      => 'isb_addons_notice',
				),

				'addon_sale_badge'                   => self::get_option_sale('addon_sale_badge'),

				'addon_outofstock_badge'             => self::get_option_outofostock('addon_outofstock_badge'),

				'addon_new_badge'					=> self::get_option_new('addon_new_badge'),

				'addon_featured_badge'				=> self::get_option_featured('addon_featured_badge'),

				'addon_tags'						=> self::get_option_tags('addon_tags'),

				'addon_categories'					=> self::get_option_categories('addon_categories'),

				'isb_overrides_notice'          => array(
					'name'    => esc_html__('Badge Overrides', '^xwc'),
					'type'    => 'html',
					'desc'    => '
					<div class="svx-option-header"><h3>' . esc_html__('Badge Overrides', '^xwc') . '</h3></div><div class="svx-option-wrapper"><div class="svx-notice svx-info">' . esc_html__('Badge overrides are used to completly replace the current badge. So, if you have a blue sale badge, and on one particular category you need other color, you can set this with the badge overrides.', '^xwc') . '</div></div>',
					'section' => 'manager',
					'id'      => 'isb_overrides_notice',
				),

				'_wcmn_sale_badge'                   => self::get_option_sale('_wcmn_sale_badge'),

				'_wcmn_outofstock_badge'             => self::get_option_outofostock('_wcmn_outofstock_badge'),

				'_wcmn_expire_in_preset'			=> self::get_option_new('_wcmn_expire_in_preset'),

				'_wcmn_featured_badge'				=> self::get_option_featured('_wcmn_featured_badge'),

				'_wcmn_tags'						=> self::get_option_tags('_wcmn_tags'),

				'_wcmn_categories'					=> self::get_option_categories('_wcmn_categories'),

				'wc_settings_isb_template_overrides' => array(
					'name'     => esc_html__('Use Woo Tempalte', '^xwc'),
					'type'     => 'checkbox',
					'desc'     => esc_html__('This is the default installation when checked, sale-flash.php template will be replaced with the plugin template.', '^xwc'),
					'id'       => 'wc_settings_isb_template_overrides',
					'default'  => 'yes',
					'autoload' => true,
					'section'  => 'installation',
					'class'     => 'svx-refresh-active-tab',
				),
				'isb_common_shop_action' => array(
					'name'    => esc_html__( 'Common Shop Init Action', '^xwc' ),
					'type'    => 'select',
					'id'      => 'isb_common_shop_action',
					'desc'    => esc_html__( 'Select a common shop init action', '^xwc' ),
					'options' => array(
						'' => esc_html__( 'Use custom action', '^xwc' ),
						'woocommerce_before_shop_loop_item' => 'woocommerce_before_shop_loop_item',
						'woocommerce_before_shop_loop_item_title' => 'woocommerce_before_shop_loop_item_title',
						'woocommerce_shop_loop_item_title' => 'woocommerce_shop_loop_item_title',
						'woocommerce_after_shop_loop_item_title' => 'woocommerce_after_shop_loop_item_title',
						'woocommerce_after_shop_loop_item' => 'woocommerce_after_shop_loop_item',
						'woocommerce_before_shop_loop_item_meta' => 'woocommerce_before_shop_loop_item_meta',
					),
					'default' => 'woocommerce_before_shop_loop_item',
					'autoload' => true,
					'section'  => 'installation',
					'condition' => 'wc_settings_isb_template_overrides:no',
				),
				'wc_settings_isb_archive_action'     => array(
					'name'     => esc_html__('Custom Shop Init Action', '^xwc'),
					'type'     => 'text',
					'desc'     => esc_html__('Use custom initialization action for products in shop page', '^xwc'),
					'id'       => 'wc_settings_isb_archive_action',
					'default'  => '',
					'autoload' => true,
					'section'  => 'installation',
					'condition' => 'wc_settings_isb_template_overrides:no',
				),
				'isb_shop_action_priority' => array(
					'name'    => esc_html__( 'Shop Action Priority', '^xwc' ),
					'type'    => 'number',
					'id'      => 'isb_shop_action_priority',
					'desc'    => esc_html__( 'Set shop action priority', '^xwc' ),
					'default' => '',
					'autoload' => true,
					'section'  => 'installation',
					'condition' => 'wc_settings_isb_template_overrides:no',
				),
				'isb_common_product_action' => array(
					'name'    => esc_html__( 'Common Product Init Action', '^xwc' ),
					'type'    => 'select',
					'id'      => 'isb_common_product_action',
					'desc'    => esc_html__( 'Select a common shop init action', '^xwc' ),
					'options' => array(
						'' => esc_html__( 'Use custom action', '^xwc' ),
						'woocommerce_before_single_product_summary' => 'woocommerce_before_single_product_summary',
						'woocommerce_product_gallery' => 'woocommerce_product_gallery',
						'woocommerce_single_product_summary' => 'woocommerce_single_product_summary',
						'woocommerce_after_single_product' => 'woocommerce_after_single_product',
						'woocommerce_product_meta_end' => 'woocommerce_product_meta_end',
						'woocommerce_product_thumbnails_after' => 'woocommerce_product_thumbnails_after',
					),
					'default' => 'woocommerce_product_gallery',
					'autoload' => true,
					'section'  => 'installation',
					'condition' => 'wc_settings_isb_template_overrides:no',
				),
				'wc_settings_isb_single_action'      => array(
					'name'     => esc_html__('Custom Product Init Action', '^xwc'),
					'type'     => 'text',
					'desc'     => esc_html__('Use custom initialization action for product pages', '^xwc'),
					'id'       => 'wc_settings_isb_single_action',
					'default'  => '',
					'autoload' => true,
					'section'  => 'installation',
					'condition' => 'wc_settings_isb_template_overrides:no',
				),
				'isb_product_action_priority' => array(
					'name'    => esc_html__( 'Product Action Priority', '^xwc' ),
					'type'    => 'number',
					'id'      => 'isb_product_action_priority',
					'desc'    => esc_html__( 'Set product action priority', '^xwc' ),
					'default' => '',
					'autoload' => true,
					'section'  => 'installation',
					'condition' => 'wc_settings_isb_template_overrides:no',
				),
				'wc_settings_isb_force_scripts'      => array(
					'name'     => esc_html__('Plugin Scripts', '^xwc'),
					'type'     => 'checkbox',
					'desc'     => esc_html__('Check this option to enable plugin scripts in all pages. This option fixes issues in Quick Views.', '^xwc'),
					'id'       => 'wc_settings_isb_force_scripts',
					'default'  => 'no',
					'autoload' => true,
					'section'  => 'installation',
				),

				'new_badge_period'                    => array(
					'name'     => esc_html__('New Badge Period', '^xwc'),
					'type'     => 'number',
					'id'       => 'new_badge_period',
					'desc'     => esc_html__('Set new product expire in period (days)', '^xwc'),
					'autoload' => false,
					'section'  => 'extra',
				),

				'wc_settings_isb_timer'              => array(
					'name'     => esc_html__('Disable Timers', '^xwc'),
					'type'     => 'multiselect',
					'desc'     => esc_html__('Select sale timers to disable.', '^xwc'),
					'id'       => 'wc_settings_isb_timer',
					'options'  => array(
						'start' => esc_html__('Starting Sale', '^xwc'),
						'end'   => esc_html__('Ending Sale', '^xwc'),
					),
					'default'  => array(),
					'autoload' => false,
					'section'  => 'extra',
					'class'    => 'svx-selectize',
				),

				'wc_settings_isb_timer_adjust'       => array(
					'name'     => esc_html__('Adjust Timer', '^xwc'),
					'type'     => 'number',
					'desc'     => esc_html__('Adjust sale timer countdown clock. Option is set in minutes.', '^xwc'),
					'id'       => 'wc_settings_isb_timer_adjust',
					'default'  => '',
					'autoload' => false,
					'section'  => 'extra',
				),

			),
		);

		return SevenVX()->_do_options($plugins, self::$plugin['label']);
	}

	static function get_option_sale($id)
	{
		return array(
			'name'     => esc_html__('Sale Badge', '^xwc'),
			'type'     => 'multiselect',
			'id'       => $id,
			'desc'     => esc_html__('Set sale badge', '^xwc'),
			'autoload' => false,
			'section'  => 'manager',
			'options'  => 'read:wcmn_isb_presets',
			'class'    => 'svx-selectize',
		);
	}

	static function get_option_outofostock($id)
	{
		return array(
			'name'     => esc_html__('Out of stock Badge', '^xwc'),
			'type'     => 'multiselect',
			'id'       => $id,
			'desc'     => esc_html__('Set out of stock badge', '^xwc'),
			'autoload' => false,
			'section'  => 'manager',
			'options'  => 'read:wcmn_isb_presets',
			'class'    => 'svx-selectize',
		);
	}

	static function get_option_new($id)
	{
		return array(
			'name'     => esc_html__('New Badge', '^xwc'),
			'type'     => 'multiselect',
			'id'       => $id,
			'desc'     => esc_html__('Set new product badge', '^xwc'),
			'autoload' => false,
			'section'  => 'manager',
			'options'  => 'read:wcmn_isb_presets',
			'class'    => 'svx-selectize',
		);
	}

	static function get_option_featured($id)
	{
		return array(
			'name'     => esc_html__('Featured Badge', '^xwc'),
			'type'     => 'multiselect',
			'id'       => $id,
			'desc'     => esc_html__('Set featured badge', '^xwc'),
			'autoload' => false,
			'section'  => 'manager',
			'options'  => 'read:wcmn_isb_presets',
			'class'    => 'svx-selectize',
		);
	}

	static function get_option_tags($id)
	{
		return array(
			'name'     => esc_html__('Tag Badges', '^xwc'),
			'type'     => 'list',
			'id'       => $id,
			'desc'     => esc_html__('Add tag badges', '^xwc'),
			'autoload' => false,
			'section'  => 'manager',
			'title'    => esc_html__('Name', '^xwc'),
			'options'  => 'list',
			'default'  => array(),
			'settings' => array(
				'name'   => array(
					'name'    => esc_html__('Name', '^xwc'),
					'type'    => 'text',
					'id'      => 'name',
					'desc'    => esc_html__('Enter override name', '^xwc'),
					'default' => '',
				),
				'term'   => array(
					'name'    => esc_html__('Term', '^xwc'),
					'type'    => 'select',
					'id'      => 'term',
					'desc'    => esc_html__('Set override term', '^xwc'),
					'options' => 'ajax:taxonomy:product_tag:has_none',
					'default' => '',
					'class'   => 'svx-selectize',
				),
				'preset' => array(
					'name'    => esc_html__('Preset', '^xwc'),
					'type'    => 'multiselect',
					'id'      => 'preset',
					'desc'    => esc_html__('Set override preset', '^xwc'),
					'options' => 'read:wcmn_isb_presets',
					'class'   => 'svx-selectize',
				),
			),
		);
	}

	static function get_option_categories($id)
	{
		return array(
			'name'     => esc_html__('Category Badges', '^xwc'),
			'type'     => 'list',
			'id'       => $id,
			'desc'     => esc_html__('Add category badges', '^xwc'),
			'autoload' => false,
			'section'  => 'manager',
			'title'    => esc_html__('Name', '^xwc'),
			'options'  => 'list',
			'default'  => array(),
			'settings' => array(
				'name'   => array(
					'name'    => esc_html__('Name', '^xwc'),
					'type'    => 'text',
					'id'      => 'name',
					'desc'    => esc_html__('Enter override name', '^xwc'),
					'default' => '',
				),
				'term'   => array(
					'name'    => esc_html__('Term', '^xwc'),
					'type'    => 'select',
					'id'      => 'term',
					'desc'    => esc_html__('Set override term', '^xwc'),
					'section' => 'manager',
					'options' => 'ajax:taxonomy:product_cat:has_none',
					'default' => '',
					'class'   => 'svx-selectize',
				),
				'preset' => array(
					'name'    => esc_html__('Preset', '^xwc'),
					'type'    => 'multiselect',
					'id'      => 'preset',
					'desc'    => esc_html__('Set override preset', '^xwc'),
					'section' => 'manager',
					'options' => 'read:wcmn_isb_presets',
					'class'   => 'svx-selectize',
				),
			),
		);
	}

	public static function call_badge()
	{
		if (!empty($_POST['isb_badge_set']['isb_preset'])) {
			$preset = self::get_preset($_POST['isb_badge_set']['isb_preset']);
			if (!empty($preset)) {
				$badge_set = array_merge(
					array('type' => 'simple'),
					$preset[0]
				);
			}
		}

		if (!isset($badge_set)) {
			$badge = isset($_POST['isb_badge_set']) ? $_POST['isb_badge_set'] : array();

			$badge_set = XforWC_Improved_Badges_GetBadge()->build_badge_set($badge);
		}

		$isb_price = self::get_mockup_product();

		switch ($badge_set['type']) {
			case 'sale':
				$badge_set['class'] = $badge_set['style'] . ' ' . $badge_set['color'] . ' ' . $badge_set['position'];
				break;

			case 'special':
				$badge_set['class'] = $badge_set['special'] . ' ' . $badge_set['color'] . ' ' . $badge_set['position'];
				break;

			case 'image':
				$badge_set['class'] = $badge_set['position'];
				break;

			case 'image-sale':
				$badge_set['class'] = $badge_set['position'];
				break;

			case 'image-special':
				$badge_set['class'] = $badge_set['position'];
				break;

			default:
				break;
		}

		ob_start();
		XforWC_Improved_Badges_GetBadge()->get_badge($badge_set['type'], $badge_set, $isb_price);
		wp_die(ob_get_clean());
		exit;
	}

	static function get_mockup_product()
	{
		return array(
			'id'         => 1,
			'type'       => 'simple',
			'regular'    => 32,
			'sale'       => 27,
			'difference' => 5,
			'percentage' => 15,
			'time'       => '2:04:50',
			'time_mode'  => 'end',
		);
	}

	public static function isb_respond()
	{
		if (!isset($_POST['isb_badge_set'])) {
			wp_die();
			exit;
		}

		self::call_badge();
	}

	public static function get_preset($preset)
	{
		if (empty($preset)) {
			return array();
		}

		$process = get_option('_wcmn_isb_preset_' . $preset, array());
		if (isset($process['name'])) {
			return array(0 => $process);
		} else {
			return array();
		}
	}
}

XforWC_Improved_Badges_Settings::init();
